@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2018 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -48,12 +48,14 @@ if ($_POST['items_id']
    $linktype   = $devicetype::getItem_DeviceType();
 
    if (count($linktype::getSpecificities())) {
+      $keys = array_keys($linktype::getSpecificities());
+      array_walk($keys, function (&$val) use ($DB) { return $DB->quoteName($val); });
       $name_field = new QueryExpression(
-         "CONCAT_WS(' - ', `" . implode('`, `', array_keys($linktype::getSpecificities())) . "`)"
-         . "AS `name`"
+         "CONCAT_WS(' - ', " . implode(', ', $keys) . ")"
+         . "AS ".$DB->quoteName("name")
       );
    } else {
-      $name_field = "id AS name";
+      $name_field = 'id AS name';
    }
    $result = $DB->request(
       [
@@ -80,7 +82,7 @@ if ($_POST['items_id']
          $devices[$row['id']] = $name;
 
       }
-      dropdown::showFromArray($linktype::getForeignKeyField(), $devices, ['multiple' => true]);
+      Dropdown::showFromArray($linktype::getForeignKeyField(), $devices, ['multiple' => true]);
    }
    echo "</td><td>";
    Dropdown::showNumber('new_devices', ['min'   => 0, 'max'   => 10]);
