@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2017 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -30,10 +30,6 @@
  * ---------------------------------------------------------------------
  */
 
-/** @file
-* @brief
-*/
-
 include ('../inc/includes.php');
 
 Session::checkRight("reports", READ);
@@ -48,18 +44,35 @@ if (isset($_POST["locations_id"]) && $_POST["locations_id"]) {
    echo "<div class='center spaced'><h2>".sprintf(__('Network report by location: %s'), $name).
         "</h2></div>";
 
-   Report::reportForNetworkInformations("`glpi_locations`
-                                          INNER JOIN `glpi_netpoints`
-                                             ON (`glpi_netpoints`.`locations_id`
-                                                   = `glpi_locations`.`id`)
-                                          INNER JOIN `glpi_networkportethernets`
-                                             ON (`glpi_networkportethernets`.`netpoints_id`
-                                                   = `glpi_netpoints`.`id`)",
-                                        "PORT_1.`id` = `glpi_networkportethernets`.`networkports_id`",
-                                        getRealQueryForTreeItem("glpi_locations", $_POST["locations_id"]),
-                                        "`glpi_locations`.`completename`, PORT_1.`name`",
-                                        "`glpi_netpoints`.`name` AS extra, ",
-                                        Netpoint::getTypeName());
+   $where = [];
+   if (!empty($_POST['locations_id'])) {
+      $sons = getSonsOf('glpi_locations', $_POST['locations_id']);
+      $where = ['glpi_locations.id' => $sons];
+   }
+
+   Report::reportForNetworkInformations(
+      'glpi_locations', //from
+      ['PORT_1' => 'id', 'glpi_networkportethernets' => 'networkports_id'], //joincrit
+      $where, //where
+      ['glpi_netpoints.name AS extra'], //select
+      [], //left join
+      [
+         'glpi_netpoints'  => [
+            'ON'  => [
+               'glpi_netpoints'  => 'locations_id',
+               'glpi_locations'  => 'id'
+            ]
+         ],
+         'glpi_networkportethernets'   => [
+            'ON'  => [
+               'glpi_networkportethernets'   => 'netpoints_id',
+               'glpi_netpoints'              => 'id'
+            ]
+         ]
+      ], //inner join
+      ['glpi_locations.completename', 'PORT_1.name'], //order
+      Netpoint::getTypeName()
+   );
 
    Html::footer();
 
