@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2017 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -30,10 +30,6 @@
  * ---------------------------------------------------------------------
  */
 
-/** @file
-* @brief
-*/
-
 /**
  *  Class used to manage LDAP replicate config
  */
@@ -86,7 +82,7 @@ class AuthLdapReplicate extends CommonDBTM {
       echo "<tr><th colspan='4'>".__('Add a LDAP directory replica'). "</th></tr>";
       echo "<tr class='tab_bg_1'><td class='center'>".__('Name')."</td>";
       echo "<td class='center'>".__('Server')."</td>";
-      echo "<td class='center'>".__('Port')."</td><td></td></tr>";
+      echo "<td class='center'>"._n('Port', 'Ports', 1)."</td><td></td></tr>";
       echo "<tr class='tab_bg_1'>";
       echo "<td class='center'><input type='text' name='name'></td>";
       echo "<td class='center'><input type='text' name='host'></td>";
