@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2017 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -30,22 +30,18 @@
  * ---------------------------------------------------------------------
  */
 
-/** @file
-* @brief
-*/
-
-
 if (!defined('GLPI_ROOT')) {
    die("Sorry. You can't access this file directly");
 }
 
-//!  Cartridge Class
 /**
- * This class is used to manage the cartridges.
+ * Cartridge class.
+ * This class is used to manage printer cartridges.
  * @see CartridgeItem
  * @author Julien Dombre
  **/
 class Cartridge extends CommonDBChild {
+   use Glpi\Features\Clonable;
 
    // From CommonDBTM
    static protected $forward_entity_to = ['Infocom'];
@@ -56,10 +52,12 @@ class Cartridge extends CommonDBChild {
    static public $itemtype             = 'CartridgeItem';
    static public $items_id             = 'cartridgeitems_id';
 
+   public function getCloneRelations() :array {
+      return [
+         Infocom::class
+      ];
+   }
 
-   /**
-    * @since version 0.84
-   **/
    function getForbiddenStandardMassiveAction() {
 
       $forbidden   = parent::getForbiddenStandardMassiveAction();
@@ -68,11 +66,6 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   /**
-    * @since version 0.85
-    *
-    * @see CommonDBTM::showMassiveActionsSubForm()
-   **/
    static function showMassiveActionsSubForm(MassiveAction $ma) {
 
       switch ($ma->getAction()) {
@@ -89,11 +82,6 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   /**
-    * @since version 0.84
-    *
-    * @see CommonDBTM::getNameField()
-   **/
    static function getNameField() {
       return 'id';
    }
@@ -117,14 +105,6 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   function post_addItem() {
-
-      Infocom::cloneItem('CartridgeItem', $this->fields["cartridgeitems_id"], $this->fields['id'],
-                         $this->getType());
-      parent::post_addItem();
-   }
-
-
    function post_updateItem($history = 1) {
 
       if (in_array('pages', $this->updates)) {
@@ -141,11 +121,6 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   /**
-    * @since version 0.84
-    *
-    * @see CommonDBTM::getPreAdditionalInfosForName
-   **/
    function getPreAdditionalInfosForName() {
 
       $ci = new CartridgeItem();
@@ -156,11 +131,6 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   /**
-    * @since version 0.85
-    *
-    * @see CommonDBTM::processMassiveActionsForOneItemtype()
-   **/
    static function processMassiveActionsForOneItemtype(MassiveAction $ma, CommonDBTM $item,
                                                        array $ids) {
 
@@ -224,20 +194,26 @@ class Cartridge extends CommonDBChild {
 
 
    /**
-    * send back to stock
+    * Send the cartridge back to stock.
     *
-    * @since version 0.85 (before name was restore)
+    * @since 0.85 (before name was restore)
+    * @param array   $input
+    * @param integer $history
+    * @return bool
     */
    function backToStock(array $input, $history = 1) {
       global $DB;
 
-      $query = "UPDATE `".$this->getTable()."`
-                SET `date_out` = NULL,
-                    `date_use` = NULL,
-                    `printers_id` = '0'
-                WHERE `id`='".$input["id"]."'";
-      if ($result = $DB->query($query)
-          && ($DB->affected_rows() > 0)) {
+      $result = $DB->update(
+         $this->getTable(), [
+            'date_out'     => 'NULL',
+            'date_use'     => 'NULL',
+            'printers_id'  => 0
+         ], [
+            'id' => $input['id']
+         ]
+      );
+      if ($result && ($DB->affectedRows() > 0)) {
          return true;
       }
       return false;
@@ -249,37 +225,46 @@ class Cartridge extends CommonDBChild {
    /**
     * Link a cartridge to a printer.
     *
-    * Link the first unused cartridge of type $Tid to the printer $pID
+    * Link the first unused cartridge of type $Tid to the printer $pID.
     *
-    * @param $tID : cartridge type identifier
-    * @param $pID : printer identifier
+    * @param integer $tID ID of the cartridge
+    * @param integer $pID : ID of the printer
     *
-    * @return boolean : true for success
+    * @return boolean True if successful
    **/
    function install($pID, $tID) {
       global $DB;
 
       // Get first unused cartridge
-      $query = "SELECT `id`
-                FROM `".$this->getTable()."`
-                WHERE (`cartridgeitems_id` = '$tID'
-                       AND `date_use` IS NULL)";
-      $result = $DB->query($query);
+      $iterator = $DB->request([
+         'SELECT' => ['id'],
+         'FROM'   => $this->getTable(),
+         'WHERE'  => [
+            'cartridgeitems_id'  => $tID,
+            'date_use'           => null
+         ],
+         'LIMIT'  => 1
+      ]);
 
-      if ($DB->numrows($result)>0) {
-         $cID = $DB->result($result, 0, 0);
-         // Mise a jour cartouche en prenant garde aux insertion multiples
-         $query = "UPDATE `".$this->getTable()."`
-                   SET `date_use` = '".date("Y-m-d")."',
-                       `printers_id` = '$pID'
-                   WHERE (`id`='$cID'
-                          AND `date_use` IS NULL)";
-
-         if ($result = $DB->query($query)
-             && ($DB->affected_rows() > 0)) {
-            $changes[0] = '0';
-            $changes[1] = '';
-            $changes[2] = __('Installing a cartridge');
+      if (count($iterator)) {
+         $result = $iterator->next();
+         $cID = $result['id'];
+         // Update cartridge taking care of multiple insertion
+         $result = $DB->update(
+            $this->getTable(), [
+               'date_use'     => date('Y-m-d'),
+               'printers_id'  => $pID
+            ], [
+               'id'        => $cID,
+               'date_use'  => null
+            ]
+         );
+         if ($result && ($DB->affectedRows() > 0)) {
+            $changes = [
+               '0',
+               '',
+               __('Installing a cartridge'),
+            ];
             Log::history($pID, 'Printer', $changes, 0, Log::HISTORY_LOG_SIMPLE_MESSAGE);
             return true;
          }
@@ -292,11 +277,9 @@ class Cartridge extends CommonDBChild {
 
 
    /**
-    * UnLink a cartridge linked to a printer
+    * Unlink a cartridge from a printer by cartridge ID.
     *
-    * UnLink the cartridge identified by $ID
-    *
-    * @param $ID : cartridge identifier
+    * @param integer $ID ID of the cartridge
     *
     * @return boolean
    **/
@@ -305,21 +288,26 @@ class Cartridge extends CommonDBChild {
 
       if ($this->getFromDB($ID)) {
          $printer = new Printer();
-         $toadd   = '';
+         $toadd   = [];
          if ($printer->getFromDB($this->getField("printers_id"))) {
-            $toadd .= ", `pages` = '".$printer->fields['last_pages_counter']."' ";
+            $toadd['pages'] = $printer->fields['last_pages_counter'];
          }
 
-         $query = "UPDATE`".$this->getTable()."`
-                   SET `date_out` = '".date("Y-m-d")."'
-                       $toadd
-                   WHERE `id`='$ID'";
+         $result = $DB->update(
+            $this->getTable(), [
+               'date_out'  => date('Y-m-d')
+            ] + $toadd, [
+               'id'  => $ID
+            ]
+         );
 
-         if ($result = $DB->query($query)
-             && ($DB->affected_rows() > 0)) {
-            $changes[0] = '0';
-            $changes[1] = '';
-            $changes[2] = __('Uninstalling a cartridge');
+         if ($result
+             && ($DB->affectedRows() > 0)) {
+            $changes = [
+               '0',
+               '',
+               __('Uninstalling a cartridge'),
+            ];
             Log::history($this->getField("printers_id"), 'Printer', $changes,
                          0, Log::HISTORY_LOG_SIMPLE_MESSAGE);
 
@@ -333,14 +321,13 @@ class Cartridge extends CommonDBChild {
    /**
     * Print the cartridge count HTML array for the cartridge item $tID
     *
-    * @param $tID              integer: cartridge item identifier.
-     *@param $alarm_threshold  integer: threshold alarm value.
-    * @param $nohtml           integer: Return value without HTML tags (default 0)
+    * @param integer         $tID      ID of the cartridge item
+    * @param integer         $alarm_threshold Alarm threshold value
+    * @param integer|boolean $nohtml          True if the return value should be without HTML tags (default 0/false)
     *
-    * @return string to display
+    * @return string String to display
    **/
    static function getCount($tID, $alarm_threshold, $nohtml = 0) {
-      global $DB;
 
       // Get total
       $total = self::getTotalNumber($tID);
@@ -387,15 +374,14 @@ class Cartridge extends CommonDBChild {
    /**
     * Print the cartridge count HTML array for the printer $pID
     *
-    * @since version 0.85
+    * @since 0.85
     *
-    * @param $pID              integer: printer identifier.
-    * @param $nohtml           integer: Return value without HTML tags (default 0)
+    * @param integer         $pID    ID of the printer
+    * @param integer|boolean $nohtml True if the return value should be without HTML tags (default 0/false)
     *
-    * @return string to display
+    * @return string String to display
    **/
    static function getCountForPrinter($pID, $nohtml = 0) {
-      global $DB;
 
       // Get total
       $total = self::getTotalNumberForPrinter($pID);
@@ -436,108 +422,122 @@ class Cartridge extends CommonDBChild {
 
 
    /**
-    * count how many cartbridge for the cartridge item $tID
+    * Count the total number of cartridges for the cartridge item $tID.
     *
-    * @param $tID integer: cartridge item identifier.
+    * @param integer $tID ID of cartridge item.
     *
-    * @return integer : number of cartridge counted.
+    * @return integer Number of cartridges counted.
    **/
    static function getTotalNumber($tID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`cartridgeitems_id` = '$tID')";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $row = $DB->request([
+         'FROM'   => self::getTable(),
+         'COUNT'  => 'cpt',
+         'WHERE'  => ['cartridgeitems_id' => $tID]
+      ])->next();
+      return $row['cpt'];
    }
 
 
    /**
-    * count how many cartbridge for the printer $pID
+    * Count the number of cartridges used for the printer $pID
     *
-    * @since version 0.85
+    * @since 0.85
     *
-    * @param $pID integer: printer identifier.
+    * @param integer $pID ID of the printer.
     *
-    * @return integer : number of cartridge counted.
+    * @return integer Number of cartridges counted.
    **/
    static function getTotalNumberForPrinter($pID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`printers_id` = '$pID')";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $row = $DB->request([
+         'FROM'   => self::getTable(),
+         'COUNT'  => 'cpt',
+         'WHERE'  => ['printers_id' => $pID]
+      ])->next();
+      return (int)$row['cpt'];
    }
 
 
    /**
-    * count how many cartridge used for the cartridge item $tID
+    * Count the number of used cartridges for the cartridge item $tID.
     *
-    * @param $tID integer: cartridge item identifier.
+    * @param integer $tID ID of the cartridge item.
     *
-    * @return integer : number of cartridge used counted.
+    * @return integer Number of used cartridges counted.
    **/
    static function getUsedNumber($tID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`cartridgeitems_id` = '$tID'
-                       AND `date_use` IS NOT NULL
-                       AND `date_out` IS NULL)";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $row = $DB->request([
+         'SELECT' => ['id'],
+         'COUNT'  => 'cpt',
+         'FROM'   => 'glpi_cartridges',
+         'WHERE'  => [
+            'cartridgeitems_id'  => $tID,
+            'date_out'           => null,
+            'NOT'                => [
+               'date_use'  => null
+            ]
+         ]
+      ])->next();
+      return (int)$row['cpt'];
    }
 
 
    /**
-    * count how many cartridge used for the printer $pID
+    * Count the number of used cartridges used for the printer $pID.
     *
-    * @since version 0.85
+    * @since 0.85
     *
-    * @param $pID integer: printer identifier.
+    * @param integer $pID ID of the printer.
     *
-    * @return integer : number of cartridge used counted.
+    * @return integer Number of used cartridge counted.
    **/
    static function getUsedNumberForPrinter($pID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`printers_id` = '$pID'
-                       AND `date_use` IS NOT NULL
-                       AND `date_out` IS NULL)";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $result = $DB->request([
+         'COUNT'  => 'cpt',
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'printers_id'  => $pID,
+            'date_out'     => null,
+            'NOT'          => ['date_use' => null]
+         ]
+      ])->next();
+      return $result['cpt'];
    }
 
 
    /**
-    * count how many old cartbridge for the cartridge item $tID
+    * Count the number of old cartridges for the cartridge item $tID.
     *
-    * @param $tID integer: cartridge item identifier.
+    * @param integer $tID ID of the cartridge item.
     *
-    * @return integer : number of old cartridge counted.
+    * @return integer Number of old cartridges counted.
    **/
    static function getOldNumber($tID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`cartridgeitems_id` = '$tID'
-                       AND `date_out` IS NOT NULL)";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $result = $DB->request([
+         'COUNT'  => 'cpt',
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'cartridgeitems_id'  => $tID,
+            'NOT'                => ['date_out' => null]
+         ]
+      ])->next();
+      return $result['cpt'];
    }
 
 
    /**
     * count how many old cartbridge for theprinter $pID
     *
-    * @since version 0.85
+    * @since 0.85
     *
     * @param $pID integer: printer identifier.
     *
@@ -546,12 +546,15 @@ class Cartridge extends CommonDBChild {
    static function getOldNumberForPrinter($pID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`printers_id` = '$pID'
-                       AND `date_out` IS NOT NULL)";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $result = $DB->request([
+         'COUNT'  => 'cpt',
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'printers_id'  => $pID,
+            'NOT'          => ['date_out' => null]
+         ]
+      ])->next();
+      return $result['cpt'];
    }
 
 
@@ -565,45 +568,48 @@ class Cartridge extends CommonDBChild {
    static function getUnusedNumber($tID) {
       global $DB;
 
-      $query = "SELECT id
-                FROM `glpi_cartridges`
-                WHERE (`cartridgeitems_id` = '$tID'
-                       AND `date_use` IS NULL)";
-      $result = $DB->query($query);
-      return $DB->numrows($result);
+      $result = $DB->request([
+         'COUNT'  => 'cpt',
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'cartridgeitems_id'  => $tID,
+            'date_use'           => null
+         ]
+      ])->next();
+      return $result['cpt'];
    }
 
 
    /**
-    * Get the dict value for the status of a cartridge
+    * Get the translated value for the status of a cartridge based on the use and out date (if any).
     *
-    * @param $date_use  date : date of use
-    * @param $date_out  date : date of delete
+    * @param string $date_use  Date of use (May be null or empty)
+    * @param string $date_out  Date of delete (May be null or empty)
     *
-    * @return string : dict value for the cartridge status.
+    * @return string : Translated value for the cartridge status.
    **/
    static function getStatus($date_use, $date_out) {
 
       if (is_null($date_use) || empty($date_use)) {
-         return _x('cartridge', 'New');
+         return _nx('cartridge', 'New', 'New', 1);
       }
       if (is_null($date_out) || empty($date_out)) {
-         return _x('cartridge', 'Used');
+         return _nx('cartridge', 'Used', 'Used', 1);
       }
-      return _x('cartridge', 'Worn');
+      return _nx('cartridge', 'Worn', 'Worn', 1);
    }
 
 
    /**
     * Print out the cartridges of a defined type
     *
-    * @param $cartitem  object   of CartridgeItem class
-    * @param $show_old  boolean  show old cartridges or not (default 0)
+    * @param CartridgeItem   $cartitem  The cartridge item
+    * @param boolean|integer $show_old  Show old cartridges or not (default 0/false)
     *
-    * @return Nothing (displays)
+    * @return boolean|void
    **/
    static function showForCartridgeItem(CartridgeItem $cartitem, $show_old = 0) {
-      global $DB, $CFG_GLPI;
+      global $DB;
 
       $tID = $cartitem->getField('id');
       if (!$cartitem->can($tID, READ)) {
@@ -611,110 +617,112 @@ class Cartridge extends CommonDBChild {
       }
       $canedit = $cartitem->can($tID, UPDATE);
 
-      $query = "SELECT COUNT(*) AS count
-                FROM `glpi_cartridges`
-                WHERE (`cartridgeitems_id` = '$tID')";
+      $where = ['glpi_cartridges.cartridgeitems_id' => $tID];
+      $order = [
+         'glpi_cartridges.date_use ASC',
+         'glpi_cartridges.date_out DESC',
+         'glpi_cartridges.date_in'
+      ];
 
-      if ($result = $DB->query($query)) {
-         $total  = $DB->result($result, 0, "count");
-
-         if (!$show_old) { // NEW
-            $where = " AND `glpi_cartridges`.`date_out` IS NULL";
-         } else { //OLD
-            $where = " AND `glpi_cartridges`.`date_out` IS NOT NULL";
-         }
-
-         $stock_time       = 0;
-         $use_time         = 0;
-         $pages_printed    = 0;
-         $nb_pages_printed = 0;
-         $ORDER = " `glpi_cartridges`.`date_use` ASC,
-                    `glpi_cartridges`.`date_out` DESC,
-                    `glpi_cartridges`.`date_in`";
-
-         if (!$show_old) {
-            $ORDER = " `glpi_cartridges`.`date_out` ASC,
-                       `glpi_cartridges`.`date_use` ASC,
-                       `glpi_cartridges`.`date_in`";
-         }
-         $query = "SELECT `glpi_cartridges`.*,
-                        `glpi_printers`.`id` AS printID,
-                        `glpi_printers`.`name` AS printname,
-                        `glpi_printers`.`init_pages_counter`
-                   FROM `glpi_cartridges`
-                   LEFT JOIN `glpi_printers`
-                        ON (`glpi_cartridges`.`printers_id` = `glpi_printers`.`id`)
-                   WHERE `glpi_cartridges`.`cartridgeitems_id` = '$tID'
-                         $where
-                   ORDER BY $ORDER";
-
-         $result = $DB->query($query);
-         $number = $DB->numrows($result);
-
-         echo "<div class='spaced'>";
-         if ($canedit && $number) {
-            $rand = mt_rand();
-            Html::openMassiveActionsForm('mass'.__CLASS__.$rand);
-            $actions = ['purge' => _x('button', 'Delete permanently'),
-                             'Infocom'.MassiveAction::CLASS_ACTION_SEPARATOR.'activate'
-                                     => __('Enable the financial and administrative information')
-                             ];
-            if ($show_old) {
-               $actions['Cartridge'.MassiveAction::CLASS_ACTION_SEPARATOR.'backtostock']
-                     = __('Back to stock');
-            }
-            $massiveactionparams = ['num_displayed'    => min($_SESSION['glpilist_limit'], $number),
-                                         'specific_actions' => $actions,
-                                         'container'        => 'mass'.__CLASS__.$rand,
-                                         'rand'             => $rand];
-            Html::showMassiveActions($massiveactionparams);
-         }
-         echo "<table class='tab_cadre_fixehov'>";
-         if (!$show_old) {
-            echo "<tr class='noHover'><th colspan='".($canedit?'7':'6')."'>".
-                  self::getCount($tID, -1)."</th>";
-            echo "</tr>";
-         } else { // Old
-            echo "<tr class='noHover'><th colspan='".($canedit?'9':'8')."'>".__('Worn cartridges');
-            echo "</th></tr>";
-         }
-         $i = 0;
-
-         $header_begin  = "<tr>";
-         $header_top    = '';
-         $header_bottom = '';
-         $header_end    = '';
-
-         if ($canedit && $number) {
-            $header_begin  .= "<th width='10'>";
-            $header_top     = Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
-            $header_bottom  = Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
-            $header_end    .= "</th>";
-         }
-         $header_end .= "<th>".__('ID')."</th>";
-         $header_end .= "<th>"._x('item', 'State')."</th>";
-         $header_end .= "<th>".__('Add date')."</th><th>".__('Use date')."</th>";
-         $header_end .= "<th>".__('Used on')."</th>";
-
-         if ($show_old) {
-            $header_end .= "<th>".__('End date')."</th>";
-            $header_end .= "<th>".__('Printer counter')."</th>";
-         }
-
-         $header_end .= "<th width='18%'>".__('Financial and administrative information')."</th>";
-         $header_end .= "</tr>";
-         echo $header_begin.$header_top.$header_end;
+      if (!$show_old) { // NEW
+         $where['glpi_cartridges.date_out'] = null;
+         $order = [
+            'glpi_cartridges.date_out ASC',
+            'glpi_cartridges.date_use ASC',
+            'glpi_cartridges.date_in'
+         ];
+      } else { //OLD
+         $where['NOT'] = ['glpi_cartridges.date_out' => null];
       }
 
+      $stock_time       = 0;
+      $use_time         = 0;
+      $pages_printed    = 0;
+      $nb_pages_printed = 0;
+
+      $iterator = $DB->request([
+         'SELECT' => [
+            'glpi_cartridges.*',
+            'glpi_printers.id AS printID',
+            'glpi_printers.name AS printname',
+            'glpi_printers.init_pages_counter'
+         ],
+         'FROM'   => self::gettable(),
+         'LEFT JOIN' => [
+            'glpi_printers'   => [
+               'FKEY'   => [
+                  self::getTable()  => 'printers_id',
+                  'glpi_printers'   => 'id'
+               ]
+            ]
+         ],
+         'WHERE'     => $where,
+         'ORDER'     => $order
+      ]);
+
+      $number = count($iterator);
+
+      echo "<div class='spaced'>";
+      if ($canedit && $number) {
+         $rand = mt_rand();
+         Html::openMassiveActionsForm('mass'.__CLASS__.$rand);
+         $actions = ['purge' => _x('button', 'Delete permanently'),
+                     'Infocom'.MassiveAction::CLASS_ACTION_SEPARATOR.'activate'
+                              => __('Enable the financial and administrative information')
+                          ];
+         if (!$show_old) {
+            $actions['Cartridge'.MassiveAction::CLASS_ACTION_SEPARATOR.'backtostock']
+                  = __('Back to stock');
+         }
+         $massiveactionparams = ['num_displayed'    => min($_SESSION['glpilist_limit'], $number),
+                                      'specific_actions' => $actions,
+                                      'container'        => 'mass'.__CLASS__.$rand,
+                                      'rand'             => $rand];
+         Html::showMassiveActions($massiveactionparams);
+      }
+      echo "<table class='tab_cadre_fixehov'>";
+      if (!$show_old) {
+         echo "<tr class='noHover'><th colspan='".($canedit?'7':'6')."'>".
+               self::getCount($tID, -1)."</th>";
+         echo "</tr>";
+      } else { // Old
+         echo "<tr class='noHover'><th colspan='".($canedit?'9':'8')."'>".__('Worn cartridges');
+         echo "</th></tr>";
+      }
+
+      $header_begin  = "<tr>";
+      $header_top    = '';
+      $header_bottom = '';
+      $header_end    = '';
+
+      if ($canedit && $number) {
+         $header_begin  .= "<th width='10'>";
+         $header_top     = Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
+         $header_bottom  = Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
+         $header_end    .= "</th>";
+      }
+      $header_end .= "<th>".__('ID')."</th>";
+      $header_end .= "<th>"._x('item', 'State')."</th>";
+      $header_end .= "<th>".__('Add date')."</th><th>".__('Use date')."</th>";
+      $header_end .= "<th>".__('Used on')."</th>";
+
+      if ($show_old) {
+         $header_end .= "<th>".__('End date')."</th>";
+         $header_end .= "<th>".__('Printer counter')."</th>";
+      }
+
+      $header_end .= "<th width='18%'>".__('Financial and administrative information')."</th>";
+      $header_end .= "</tr>";
+      echo $header_begin.$header_top.$header_end;
+
       $pages = [];
 
       if ($number) {
-         while ($data = $DB->fetch_assoc($result)) {
+         while ($data = $iterator->next()) {
             $date_in  = Html::convDate($data["date_in"]);
             $date_use = Html::convDate($data["date_use"]);
             $date_out = Html::convDate($data["date_out"]);
             $printer  = $data["printers_id"];
-            $page     = $data["pages"];
 
             echo "<tr class='tab_bg_1'>";
             if ($canedit) {
@@ -733,8 +741,7 @@ class Cartridge extends CommonDBChild {
                   if ($_SESSION['glpiis_ids_visible'] || empty($printname)) {
                      $printname = sprintf(__('%1$s (%2$s)'), $printname, $data["printID"]);
                   }
-                  echo "<a href='".$CFG_GLPI["root_doc"]."/front/printer.form.php?id=".
-                        $data["printID"]."'><span class='b'>".$printname."</span></a>";
+                  echo "<a href='".Printer::getFormURLWithID($data["printID"])."'><span class='b'>".$printname."</span></a>";
                } else {
                   echo NOT_AVAILABLE;
                }
@@ -784,10 +791,10 @@ class Cartridge extends CommonDBChild {
             }
             echo "<tr class='tab_bg_2'><td colspan='".($canedit?'4':'3')."'>&nbsp;</td>";
             echo "<td class='center b'>".__('Average time in stock')."<br>";
-            echo round($stock_time/$number/60/60/24/30.5, 1)." ".__('month')."</td>";
+            echo round($stock_time/$number/60/60/24/30.5, 1)." "._n('month', 'months', 1)."</td>";
             echo "<td>&nbsp;</td>";
             echo "<td class='center b'>".__('Average time in use')."<br>";
-            echo round($use_time/$number/60/60/24/30.5, 1)." ".__('month')."</td>";
+            echo round($use_time/$number/60/60/24/30.5, 1)." "._n('month', 'months', 1)."</td>";
             echo "<td class='center b'>".__('Average number of printed pages')."<br>";
             echo round($pages_printed/$nb_pages_printed)."</td>";
             echo "<td colspan='".($canedit?'3':'1')."'>&nbsp;</td></tr>";
@@ -811,10 +818,9 @@ class Cartridge extends CommonDBChild {
     *
     * @param $cartitem  CartridgeItem object
     *
-    * @return Nothing (displays)
+    * @return boolean|void
    **/
    static function showAddForm(CartridgeItem $cartitem) {
-      global $CFG_GLPI;
 
       $ID = $cartitem->getField('id');
       if (!$cartitem->can($ID, UPDATE)) {
@@ -843,12 +849,12 @@ class Cartridge extends CommonDBChild {
    /**
     * Show installed cartridges
     *
-    * @since version 0.84 (before showInstalled)
+    * @since 0.84 (before showInstalled)
     *
-    * @param $printer            Printer object
-    * @param $old       boolean  old cartridges or not ? (default 0)
+    * @param Printer         $printer Printer object
+    * @param boolean|integer $old     Old cartridges or not? (default 0/false)
     *
-    * @return nothing (display)
+    * @return boolean|void
    **/
    static function showForPrinter(Printer $printer, $old = 0) {
       global $DB, $CFG_GLPI;
@@ -860,30 +866,49 @@ class Cartridge extends CommonDBChild {
       $canedit = Session::haveRight("cartridge", UPDATE);
       $rand    = mt_rand();
 
-      $query = "SELECT `glpi_cartridgeitems`.`id` AS tID,
-                       `glpi_cartridgeitems`.`is_deleted`,
-                       `glpi_cartridgeitems`.`ref` AS ref,
-                       `glpi_cartridgeitems`.`name` AS type,
-                       `glpi_cartridges`.`id`,
-                       `glpi_cartridges`.`pages` AS pages,
-                       `glpi_cartridges`.`date_use` AS date_use,
-                       `glpi_cartridges`.`date_out` AS date_out,
-                       `glpi_cartridges`.`date_in` AS date_in,
-                       `glpi_cartridgeitemtypes`.`name` AS typename
-                FROM `glpi_cartridges`,
-                     `glpi_cartridgeitems`
-                LEFT JOIN `glpi_cartridgeitemtypes`
-                  on (`glpi_cartridgeitems`.`cartridgeitemtypes_id` = `glpi_cartridgeitemtypes`.`id`)
-                WHERE (`glpi_cartridges`.`date_out` IS ".($old?"NOT":"")." NULL
-                       AND `glpi_cartridges`.`printers_id` = '$instID'
-                       AND `glpi_cartridges`.`cartridgeitems_id` = `glpi_cartridgeitems`.`id`)
-                ORDER BY `glpi_cartridges`.`date_out` ASC,
-                         `glpi_cartridges`.`date_use` DESC,
-                         `glpi_cartridges`.`date_in`";
+      $where = ['glpi_cartridges.printers_id' => $instID];
+      if ($old) {
+         $where['NOT'] = ['glpi_cartridges.date_out' => null];
+      } else {
+         $where['glpi_cartridges.date_out'] = null;
+      }
+      $iterator = $DB->request([
+         'SELECT'    => [
+            'glpi_cartridgeitems.id AS tID',
+            'glpi_cartridgeitems.is_deleted',
+            'glpi_cartridgeitems.ref AS ref',
+            'glpi_cartridgeitems.name AS type',
+            'glpi_cartridges.id',
+            'glpi_cartridges.pages AS pages',
+            'glpi_cartridges.date_use AS date_use',
+            'glpi_cartridges.date_out AS date_out',
+            'glpi_cartridges.date_in AS date_in',
+            'glpi_cartridgeitemtypes.name AS typename'
+         ],
+         'FROM'      => self::getTable(),
+         'LEFT JOIN' => [
+            'glpi_cartridgeitems'      => [
+               'FKEY'   => [
+                  self::getTable()        => 'cartridgeitems_id',
+                  'glpi_cartridgeitems'   => 'id'
+               ]
+            ],
+            'glpi_cartridgeitemtypes'  => [
+               'FKEY'   => [
+                  'glpi_cartridgeitems'      => 'cartridgeitemtypes_id',
+                  'glpi_cartridgeitemtypes'  => 'id'
+               ]
+            ]
+         ],
+         'WHERE'     => $where,
+         'ORDER'     => [
+            'glpi_cartridges.date_out ASC',
+            'glpi_cartridges.date_use DESC',
+            'glpi_cartridges.date_in',
+         ]
+      ]);
 
-      $result = $DB->query($query);
-      $number = $DB->numrows($result);
-      $i      = 0;
+      $number = count($iterator);
 
       if ($canedit && !$old) {
          echo "<div class='firstbloc'>";
@@ -891,17 +916,14 @@ class Cartridge extends CommonDBChild {
          echo "<table class='tab_cadre_fixe'>";
          echo "<tr><td class='center tab_bg_2' width='50%'>";
          echo "<input type='hidden' name='printers_id' value='$instID'>\n";
-         $installok = false;
-         $cpt = '';
          if (CartridgeItem::dropdownForPrinter($printer)) {
             //TRANS : multiplier
             echo "</td><td>".__('x')."&nbsp;";
             Dropdown::showNumber("nbcart", ['value' => 1,
                                                  'min'   => 1,
                                                  'max'   => 5]);
-            $installok = true;
             echo "</td><td><input type='submit' name='install' value=\""._sx('button', 'Install')."\"
-                          ".($installok?'':'disabled')." class='submit'>";
+                                  class='submit'>";
 
          } else {
             echo __('No cartridge available');
@@ -949,13 +971,11 @@ class Cartridge extends CommonDBChild {
 
       $header_begin  = "<tr>";
       $header_top    = '';
-      $header_bottom = '';
       $header_end    = '';
 
       if ($canedit) {
          $header_begin  .= "<th width='10'>";
          $header_top    .= Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
-         $header_bottom .= Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
          $header_end    .= "</th>";
       }
       $header_end .= "<th>".__('ID')."</th><th>"._n('Cartridge model', 'Cartridge models', 1)."</th>";
@@ -975,28 +995,28 @@ class Cartridge extends CommonDBChild {
       $pages_printed    = 0;
       $nb_pages_printed = 0;
 
-      while ($data = $DB->fetch_assoc($result)) {
+      while ($data = $iterator->next()) {
          $cart_id    = $data["id"];
          $typename   = $data["typename"];
          $date_in    = Html::convDate($data["date_in"]);
          $date_use   = Html::convDate($data["date_use"]);
          $date_out   = Html::convDate($data["date_out"]);
-         $viewitemjs = ($canedit ? "style='cursor:pointer' onClick=\"viewEditCartridge".$data['id'].
+         $viewitemjs = ($canedit ? "style='cursor:pointer' onClick=\"viewEditCartridge".$cart_id.
                         "$rand();\"" : '');
          echo "<tr class='tab_bg_1".($data["is_deleted"]?"_2":"")."'>";
          if ($canedit) {
             echo "<td width='10'>";
-            Html::showMassiveActionCheckBox(__CLASS__, $data["id"]);
+            Html::showMassiveActionCheckBox(__CLASS__, $cart_id);
             echo "</td>";
          }
          echo "<td class='center' $viewitemjs>";
          if ($canedit) {
             echo "\n<script type='text/javascript' >\n";
-            echo "function viewEditCartridge". $data["id"]."$rand() {\n";
+            echo "function viewEditCartridge". $cart_id."$rand() {\n";
             $params = ['type'        => __CLASS__,
                             'parenttype'  => 'Printer',
                             'printers_id' => $printer->fields["id"],
-                            'id'          => $data["id"]];
+                            'id'          => $cart_id];
             Ajax::updateItemJsCode("viewcartridge$rand",
                                    $CFG_GLPI["root_doc"]."/ajax/viewsubitem.php", $params);
             echo "};";
@@ -1004,7 +1024,7 @@ class Cartridge extends CommonDBChild {
          }
          echo $data["id"]."</td>";
          echo "<td class='center' $viewitemjs>";
-         echo "<a href=\"".$CFG_GLPI["root_doc"]."/front/cartridgeitem.form.php?id=".$data["tID"]."\">";
+         echo "<a href=\"".CartridgeItem::getFormURLWithID($data["tID"])."\">";
          printf(__('%1$s - %2$s'), $data["type"], $data["ref"]);
          echo "</a></td>";
          echo "<td class='center' $viewitemjs>".$typename."</td>";
@@ -1072,16 +1092,17 @@ class Cartridge extends CommonDBChild {
    }
 
 
-   /** form for Cartridge
+   /**
+    * Show form for Cartridge
+    * @since 0.84
     *
-    * @since version 0.84
-    *
-    * @param $ID      integer  Id of the cartridge
-    * @param $options array    of possible options:
+    * @param integer $ID       Id of the cartridge
+    * @param array   $options  Array of possible options:
     *     - parent Object : the printers where the cartridge is used
-   **/
+    *
+    * @return boolean False if there was a rights issue. Otherwise, returns true.
+    */
    function showForm($ID, $options = []) {
-      global $DB, $CFG_GLPI;
 
       if (isset($options['parent']) && !empty($options['parent'])) {
          $printer = $options['parent'];
@@ -1149,29 +1170,31 @@ class Cartridge extends CommonDBChild {
    /**
     * Get notification parameters by entity
     *
-    * @param entity the entity (default 0)
+    * @param integer $entity The entity (default 0)
+    * @return array Array of notification parameters
     */
    static function getNotificationParameters($entity = 0) {
       global $DB, $CFG_GLPI;
 
       //Look for parameters for this entity
-      $query = "SELECT `cartridges_alert_repeat`
-                FROM `glpi_entities`
-                WHERE `id` = '$entity'";
-      $iterator = $DB->request($query);
+      $iterator = $DB->request([
+         'SELECT' => ['cartridges_alert_repeat'],
+         'FROM'   => 'glpi_entities',
+         'WHERE'  => ['id' => $entity]
+      ]);
 
-      if (!$iterator->numrows()) {
+      if (!count($iterator)) {
          //No specific parameters defined, taking global configuration params
          return $CFG_GLPI['cartridges_alert_repeat'];
 
       } else {
-         $datas = $iterator->next();
+         $data = $iterator->next();
          //This entity uses global parameters -> return global config
-         if ($datas['cartridges_alert_repeat'] == -1) {
+         if ($data['cartridges_alert_repeat'] == -1) {
             return $CFG_GLPI['cartridges_alert_repeat'];
          }
          // ELSE Special configuration for this entity
-         return $datas['cartridges_alert_repeat'];
+         return $data['cartridges_alert_repeat'];
       }
    }
 
@@ -1198,6 +1221,11 @@ class Cartridge extends CommonDBChild {
    }
 
 
+   /**
+    * Count the number of cartridges associated with the given cartridge item.
+    * @param CartridgeItem $item CartridgeItem object
+    * @return integer
+    */
    static function countForCartridgeItem(CartridgeItem $item) {
 
       return countElementsInTable(['glpi_cartridges'], ['glpi_cartridges.cartridgeitems_id' => $item->getField('id')]);
@@ -1205,8 +1233,10 @@ class Cartridge extends CommonDBChild {
 
 
    /**
-    * @param $item Printer object
-   **/
+    * Count the number of cartridges associated with the given printer.
+    * @param Printer $item Printer object
+    * @return integer
+    */
    static function countForPrinter(Printer $item) {
 
       return countElementsInTable(['glpi_cartridges'], ['glpi_cartridges.printers_id' => $item->getField('id')]);
@@ -1234,4 +1264,9 @@ class Cartridge extends CommonDBChild {
       return $ci->getRights($interface);
    }
 
+
+   static function getIcon() {
+      return "fas fa-fill-drip";
+   }
+
 }
