@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -194,11 +194,11 @@ class Change extends CommonITILObject {
          case __CLASS__ :
             switch ($tabnum) {
                case 1 :
-                  $item->showAnalysisForm();
+                  $item->showAnalysisForm($item->getID());
                   break;
 
                case 3 :
-                  $item->showPlanForm();
+                  $item->showPlanForm($item->getID());
                   break;
 
                case 4 :
@@ -1166,8 +1166,17 @@ class Change extends CommonITILObject {
       echo "</div>";
 
       echo $tt->getEndHiddenFieldValue('content', $this);
+      $this->handleFileUploadField($tt, [
+         'colwidth' => $colsize1
+      ]);
+
       echo "</td></tr>";
 
+      if (!$ID) {
+         $this->showAnalysisForm($ID, $options, $tt);
+         $this->showPlanForm($ID, $options, $tt);
+      }
+
       $options['colspan'] = 2;
 
       if (!$options['template_preview']) {
@@ -1205,91 +1214,162 @@ class Change extends CommonITILObject {
    /**
     * Form to add an analysis to a change
    **/
-   function showAnalysisForm() {
+   function showAnalysisForm($ID = false, $options = [], $tt = null) {
 
       $this->check($this->getField('id'), READ);
       $canedit = $this->canEdit($this->getField('id'));
 
-      $options            = [];
-      $options['canedit'] = false;
-      CommonDBTM::showFormHeader($options);
+      if ($tt == null) {
+         if (!isset($options['template_preview'])) {
+            $options['template_preview'] = 0;
+         }
 
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>".__('Impacts')."</td><td colspan='3'>";
+         $tt = $this->getITILTemplateToUse(
+            $options['template_preview'],
+            $this->getType(),
+            ($ID ? $this->fields['itilcategories_id'] : $options['itilcategories_id']),
+            ($ID ? $this->fields['entities_id'] : $options['entities_id'])
+         );
+      }
+
+      if ($ID) {
+         $options            = [];
+         $options['canedit'] = false;
+         CommonDBTM::showFormHeader($options);
+      }
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$tt->getBeginHiddenFieldText('impactcontent');
+      printf(__('%1$s%2$s'), __('Impacts'), $tt->getMandatoryMark('impactcontent'));
+      echo $tt->getEndHiddenFieldText('impactcontent')."</th>";
+      echo "<td colspan='3'>";
+      echo $tt->getBeginHiddenFieldValue('impactcontent');
       if ($canedit) {
-         echo "<textarea id='impactcontent' name='impactcontent' rows='6' cols='110'>";
+         echo "<textarea ". ($tt->isMandatoryField('impactcontent') ? " required='required'" : '') .
+         " id='impactcontent' name='impactcontent' rows='6' cols='110'>";
          echo $this->getField('impactcontent');
          echo "</textarea>";
       } else {
          echo $this->getField('impactcontent');
       }
-      echo "</td></tr>";
+      echo $tt->getEndHiddenFieldValue('impactcontent', $this);
+      echo "</td>";
+      echo "</tr>";
 
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>".__('Control list')."</td><td colspan='3'>";
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$tt->getBeginHiddenFieldText('controlistcontent');
+      printf(__('%1$s%2$s'), __('Control list'), $tt->getMandatoryMark('controlistcontent'));
+      echo $tt->getEndHiddenFieldText('controlistcontent')."</th>";
+      echo "<td colspan='3'>";
+      echo $tt->getBeginHiddenFieldValue('controlistcontent');
       if ($canedit) {
-         echo "<textarea id='controlistcontent' name='controlistcontent' rows='6' cols='110'>";
+         echo "<textarea ". ($tt->isMandatoryField('controlistcontent') ? " required='required'" : '') .
+         " id='controlistcontent' name='controlistcontent' rows='6' cols='110'>";
          echo $this->getField('controlistcontent');
          echo "</textarea>";
       } else {
          echo $this->getField('controlistcontent');
       }
+      echo $tt->getEndHiddenFieldValue('controlistcontent', $this);
+      echo "</td>";
+      echo "</tr>";
+
       echo "</td></tr>";
 
-      $options['candel']  = false;
-      $options['canedit'] = $canedit;
-      $this->showFormButtons($options);
+      if ($ID) {
+         $options['candel']  = false;
+         $options['canedit'] = $canedit;
+         $this->showFormButtons($options);
+      }
 
    }
 
    /**
     * Form to add an analysis to a change
    **/
-   function showPlanForm() {
+   function showPlanForm($ID = false, $options = [], $tt = null) {
 
       $this->check($this->getField('id'), READ);
       $canedit            = $this->canEdit($this->getField('id'));
 
-      $options            = [];
-      $options['canedit'] = false;
-      CommonDBTM::showFormHeader($options);
+      if ($ID) {
+         $options            = [];
+         $options['canedit'] = false;
+         CommonDBTM::showFormHeader($options);
+      }
 
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>".__('Deployment plan')."</td><td colspan='3'>";
+      if ($tt == null) {
+         if (!isset($options['template_preview'])) {
+            $options['template_preview'] = 0;
+         }
+
+         $tt = $this->getITILTemplateToUse(
+            $options['template_preview'],
+            $this->getType(),
+            ($ID ? $this->fields['itilcategories_id'] : $options['itilcategories_id']),
+            ($ID ? $this->fields['entities_id'] : $options['entities_id'])
+         );
+      }
+
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$tt->getBeginHiddenFieldText('rolloutplancontent');
+      printf(__('%1$s%2$s'), __('Deployment plan'), $tt->getMandatoryMark('rolloutplancontent'));
+      echo $tt->getEndHiddenFieldText('rolloutplancontent')."</th>";
+      echo "<td colspan='3'>";
+      echo $tt->getBeginHiddenFieldValue('rolloutplancontent');
       if ($canedit) {
-         echo "<textarea id='rolloutplancontent' name='rolloutplancontent' rows='6' cols='110'>";
+         echo "<textarea ". ($tt->isMandatoryField('rolloutplancontent') ? " required='required'" : '') .
+         " id='rolloutplancontent' name='rolloutplancontent' rows='6' cols='110'>";
          echo $this->getField('rolloutplancontent');
          echo "</textarea>";
       } else {
          echo $this->getField('rolloutplancontent');
       }
-      echo "</td></tr>";
+      echo $tt->getEndHiddenFieldValue('rolloutplancontent', $this);
+      echo "</td>";
+      echo "</tr>";
 
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>".__('Backup plan')."</td><td colspan='3'>";
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$tt->getBeginHiddenFieldText('backoutplancontent');
+      printf(__('%1$s%2$s'), __('Backup plan'), $tt->getMandatoryMark('backoutplancontent'));
+      echo $tt->getEndHiddenFieldText('backoutplancontent')."</th>";
+      echo "<td colspan='3'>";
+      echo $tt->getBeginHiddenFieldValue('backoutplancontent');
       if ($canedit) {
-         echo "<textarea id='backoutplancontent' name='backoutplancontent' rows='6' cols='110'>";
+         echo "<textarea ". ($tt->isMandatoryField('backoutplancontent') ? " required='required'" : '') .
+         " id='backoutplancontent' name='backoutplancontent' rows='6' cols='110'>";
          echo $this->getField('backoutplancontent');
          echo "</textarea>";
       } else {
          echo $this->getField('backoutplancontent');
       }
-      echo "</td></tr>";
+      echo $tt->getEndHiddenFieldValue('backoutplancontent', $this);
+      echo "</td>";
+      echo "</tr>";
 
-      echo "<tr class='tab_bg_2'>";
-      echo "<td>".__('Checklist')."</td><td colspan='3'>";
+      echo "<tr class='tab_bg_1'>";
+      echo "<th>".$tt->getBeginHiddenFieldText('checklistcontent');
+      printf(__('%1$s%2$s'), __('Checklist'), $tt->getMandatoryMark('checklistcontent'));
+      echo $tt->getEndHiddenFieldText('checklistcontent')."</th>";
+      echo "<td colspan='3'>";
+      echo $tt->getBeginHiddenFieldValue('checklistcontent');
       if ($canedit) {
-         echo "<textarea id='checklistcontent' name='checklistcontent' rows='6' cols='110'>";
+         echo "<textarea ". ($tt->isMandatoryField('checklistcontent') ? " required='required'" : '') .
+         " id='checklistcontent' name='checklistcontent' rows='6' cols='110'>";
          echo $this->getField('checklistcontent');
          echo "</textarea>";
       } else {
          echo $this->getField('checklistcontent');
       }
-      echo "</td></tr>";
+      echo $tt->getEndHiddenFieldValue('checklistcontent', $this);
+      echo "</td>";
+      echo "</tr>";
 
-      $options['candel']  = false;
-      $options['canedit'] = $canedit;
-      $this->showFormButtons($options);
+      if ($ID) {
+         $options['candel']  = false;
+         $options['canedit'] = $canedit;
+         $this->showFormButtons($options);
+      }
 
    }
 
