@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2017 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -30,9 +30,9 @@
  * ---------------------------------------------------------------------
  */
 
-/** @file
-* @brief Virtual machine management
-*/
+/**
+ * Virtual machine management
+ */
 
 if (!defined('GLPI_ROOT')) {
    die("Sorry. You can't access this file directly");
@@ -56,9 +56,6 @@ class ComputerVirtualMachine extends CommonDBChild {
    }
 
 
-   /**
-    * @see CommonGLPI::getTabNameForItem()
-   **/
    function getTabNameForItem(CommonGLPI $item, $withtemplate = 0) {
 
       if (!$withtemplate
@@ -66,7 +63,7 @@ class ComputerVirtualMachine extends CommonDBChild {
           && Computer::canView()) {
          $nb = 0;
          if ($_SESSION['glpishow_count_on_tabs']) {
-            $nb = countElementsInTable('glpi_computervirtualmachines',
+            $nb = countElementsInTable(self::getTable(),
                                       ['computers_id' => $item->getID(), 'is_deleted' => 0 ]);
          }
          return self::createTabEntry(self::getTypeName(), $nb);
@@ -75,11 +72,6 @@ class ComputerVirtualMachine extends CommonDBChild {
    }
 
 
-   /**
-    * @see CommonGLPI::defineTabs()
-    *
-    * @since version 0.85
-   **/
    function defineTabs($options = []) {
 
       $ong = [];
@@ -89,11 +81,6 @@ class ComputerVirtualMachine extends CommonDBChild {
    }
 
 
-   /**
-    * @param $item         CommonGLPI object
-    * @param $tabnum       (default 1)
-    * @param $withtemplate (default 0)
-   **/
    static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0) {
 
       self::showForVirtualMachine($item);
@@ -120,7 +107,6 @@ class ComputerVirtualMachine extends CommonDBChild {
     * @return true if displayed  false if item not found or not right to display
    **/
    function showForm($ID, $options = []) {
-      global $CFG_GLPI;
 
       if (!Session::haveRight("computer", UPDATE)) {
          return false;
@@ -144,7 +130,7 @@ class ComputerVirtualMachine extends CommonDBChild {
       }
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".__('Computer')."</td>";
+      echo "<td>".Computer::getTypeName(1)."</td>";
       echo "<td>".$comp->getLink()."</td>";
       if (Plugin::haveImport()) {
          echo "<td>".__('Automatic inventory')."</td>";
@@ -170,18 +156,18 @@ class ComputerVirtualMachine extends CommonDBChild {
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".__('Virtualization system')."</td>";
+      echo "<td>".VirtualMachineType::getTypeName(1)."</td>";
       echo "<td>";
       VirtualMachineType::dropdown(['value' => $this->fields['virtualmachinetypes_id']]);
       echo "</td></tr>";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".__('Virtualization model')."</td>";
+      echo "<td>".VirtualMachineSystem::getTypeName(1)."</td>";
       echo "<td>";
       VirtualMachineSystem::dropdown(['value' => $this->fields['virtualmachinesystems_id']]);
       echo "</td></tr>";
 
-      echo "<tr class='tab_bg_1'><td>".__('State of the virtual machine')."</td>";
+      echo "<tr class='tab_bg_1'><td>".VirtualMachineState::getTypeName(1)."</td>";
       echo "<td>";
       VirtualMachineState::dropdown(['value' => $this->fields['virtualmachinestates_id']]);
       echo "</td></tr>";
@@ -206,7 +192,7 @@ class ComputerVirtualMachine extends CommonDBChild {
       echo "</tr>";
 
       echo "<tr class='tab_bg_1'>";
-      echo "<td>".sprintf(__('%1$s (%2$s)'), __('Memory'), __('Mio'))."</td>";
+      echo "<td>".sprintf(__('%1$s (%2$s)'), _n('Memory', 'Memories', 1), __('Mio'))."</td>";
       echo "<td>";
       Html::autocompletionTextField(
          $this,
@@ -245,30 +231,33 @@ class ComputerVirtualMachine extends CommonDBChild {
     *
     * @param $comp   Computer object that represents the virtual machine
     *
-    * @return Nothing (call to classes members)
+    * @return void
    **/
    static function showForVirtualMachine(Computer $comp) {
-      global $DB;
 
       $ID = $comp->fields['id'];
 
       if (!$comp->getFromDB($ID) || !$comp->can($ID, READ)) {
-         return false;
+         return;
       }
-      $canedit = $comp->canEdit($ID);
 
       echo "<div class='center'>";
 
       if (isset($comp->fields['uuid']) && ($comp->fields['uuid'] != '')) {
-         $where = "LOWER(`uuid`)".self::getUUIDRestrictRequest($comp->fields['uuid']);
-         $hosts = getAllDatasFromTable('glpi_computervirtualmachines', $where);
+         $hosts = getAllDataFromTable(
+            self::getTable(), [
+               'RAW' => [
+                  'LOWER(uuid)' => self::getUUIDRestrictCriteria($comp->fields['uuid'])
+               ]
+            ]
+         );
 
          if (!empty($hosts)) {
             echo "<table class='tab_cadre_fixehov'>";
             echo  "<tr class='noHover'><th colspan='2' >".__('List of virtualized environments')."</th></tr>";
 
             $header = "<tr><th>".__('Name')."</th>";
-            $header .= "<th>".__('Entity')."</th>";
+            $header .= "<th>".Entity::getTypeName(1)."</th>";
             $header .= "</tr>";
             echo $header;
 
@@ -278,7 +267,7 @@ class ComputerVirtualMachine extends CommonDBChild {
                echo "<tr class='tab_bg_2'>";
                echo "<td>";
                if ($computer->can($host['computers_id'], READ)) {
-                  echo "<a href='computer.form.php?id=".$computer->fields['id']."'>";
+                  echo "<a href='".Computer::getFormURLWithID($computer->fields['id'])."'>";
                   echo $computer->fields['name']."</a>";
                   $tooltip = "<table><tr><td>".__('Name')."</td><td>".$computer->fields['name'].
                              '</td></tr>';
@@ -312,12 +301,11 @@ class ComputerVirtualMachine extends CommonDBChild {
    /**
     * Print the computers disks
     *
-    * @param $comp Computer object
+    * @param Computer $comp Computer object
     *
-    * @return Nothing (call to classes members)
+    * @return void|boolean (display) Returns false if there is a rights error.
    **/
    static function showForComputer(Computer $comp) {
-      global $DB;
 
       $ID = $comp->fields['id'];
 
@@ -328,20 +316,27 @@ class ComputerVirtualMachine extends CommonDBChild {
 
       if ($canedit) {
          echo "<div class='center firstbloc'>".
-                "<a class='vsubmit' href='computervirtualmachine.form.php?computers_id=$ID'>";
+                "<a class='vsubmit' href='".ComputerVirtualMachine::getFormURL()."?computers_id=$ID'>";
          echo __('Add a virtual machine');
          echo "</a></div>\n";
       }
 
       echo "<div class='center'>";
 
-      $virtualmachines = getAllDatasFromTable('glpi_computervirtualmachines',
-                                              "`computers_id` = '$ID' AND `is_deleted` = '0'", false, 'name');
+      $virtualmachines = getAllDataFromTable(
+         self::getTable(), [
+            'WHERE'  => [
+               'computers_id' => $ID,
+               'is_deleted'   => 0
+            ],
+            'ORDER'  => 'name'
+         ]
+      );
 
       echo "<table class='tab_cadre_fixehov'>";
 
       Session::initNavigateListItems('ComputerVirtualMachine',
-                                     sprintf(__('%1$s = %2$s'), __('Computer'),
+                                     sprintf(__('%1$s = %2$s'), Computer::getTypeName(1),
                                              (empty($comp->fields['name'])
                                                 ? "($ID)" : $comp->fields['name'])));
 
@@ -351,15 +346,16 @@ class ComputerVirtualMachine extends CommonDBChild {
          echo "<tr class='noHover'><th colspan='10'>".__('List of virtualized environments')."</th></tr>";
 
          $header = "<tr><th>".__('Name')."</th>";
+         $header .= "<th>"._n('Comment', 'Comments', 1)."</th>";
          if (Plugin::haveImport()) {
             $header .= "<th>".__('Automatic inventory')."</th>";
          }
-         $header .= "<th>".__('Virtualization system')."</th>";
-         $header .= "<th>".__('Virtualization model')."</th>";
+         $header .= "<th>".VirtualMachineType::getTypeName(1)."</th>";
+         $header .= "<th>".VirtualMachineSystem::getTypeName(1)."</th>";
          $header .= "<th>".__('State')."</th>";
          $header .= "<th>".__('UUID')."</th>";
          $header .= "<th>"._x('quantity', 'Processors number')."</th>";
-         $header .= "<th>".sprintf(__('%1$s (%2$s)'), __('Memory'), __('Mio'))."</th>";
+         $header .= "<th>".sprintf(__('%1$s (%2$s)'), _n('Memory', 'Memories', 1), __('Mio'))."</th>";
          $header .= "<th>".__('Machine')."</th>";
          $header .= "</tr>";
          echo $header;
@@ -369,6 +365,7 @@ class ComputerVirtualMachine extends CommonDBChild {
             $vm->getFromDB($virtualmachine['id']);
             echo "<tr class='tab_bg_2'>";
             echo "<td>".$vm->getLink()."</td>";
+            echo "<td>".$virtualmachine['comment']."</td>";
             if (Plugin::haveImport()) {
                echo "<td>".Dropdown::getYesNo($vm->isDynamic())."</td>";
             }
@@ -391,7 +388,7 @@ class ComputerVirtualMachine extends CommonDBChild {
             if ($link_computer = self::findVirtualMachine($virtualmachine)) {
                $computer = new Computer();
                if ($computer->can($link_computer, READ)) {
-                  $url  = "<a href='computer.form.php?id=".$link_computer."'>";
+                  $url  = "<a href='".$computer->getFormURLWithID($link_computer)."'>";
                   $url .= $computer->fields["name"]."</a>";
 
                   $tooltip = "<table><tr><td>".__('Name')."</td><td>".$computer->fields['name'].
@@ -422,12 +419,14 @@ class ComputerVirtualMachine extends CommonDBChild {
    /**
     * Get correct uuid sql search for virtualmachines
     *
-    * @param $uuid the uuid given
+    * @since 9.3.1
     *
-    * @return the restrict which contains uuid, uuid with first block flipped,
+    * @param string $uuid the uuid given
+    *
+    * @return array the restrict SQL clause which contains uuid, uuid with first block flipped,
     * uuid with 3 first block flipped
    **/
-   static function getUUIDRestrictRequest($uuid) {
+   static function getUUIDRestrictCriteria($uuid) {
 
       //More infos about uuid, please see wikipedia :
       //http://en.wikipedia.org/wiki/Universally_unique_identifier
@@ -446,17 +445,17 @@ class ComputerVirtualMachine extends CommonDBChild {
 
       //Case two : why this code ? Because some dmidecode < 2.10 is buggy.
       //On unix is flips first block of uuid and on windows flips 3 first blocks...
-      $in      = " IN ('".strtolower($uuid)."'";
-      $regexes = ["/([\w]{2})([\w]{2})([\w]{2})([\w]{2})(.*)/" => "$4$3$2$1$5",
-                       "/([\w]{2})([\w]{2})([\w]{2})([\w]{2})-([\w]{2})([\w]{2})-([\w]{2})([\w]{2})(.*)/"
-                                                                    => "$4$3$2$1-$6$5-$8$7$9"];
+      $in      = [strtolower($uuid)];
+      $regexes = [
+         "/([\w]{2})([\w]{2})([\w]{2})([\w]{2})(.*)/"                                        => "$4$3$2$1$5",
+         "/([\w]{2})([\w]{2})([\w]{2})([\w]{2})-([\w]{2})([\w]{2})-([\w]{2})([\w]{2})(.*)/"  => "$4$3$2$1-$6$5-$8$7$9"
+      ];
       foreach ($regexes as $pattern => $replace) {
          $reverse_uuid = preg_replace($pattern, $replace, $uuid);
          if ($reverse_uuid) {
-            $in .= " ,'".strtolower($reverse_uuid)."'";
+            $in[] = strtolower($reverse_uuid);
          }
       }
-      $in .= ")";
 
       return $in;
    }
@@ -465,9 +464,9 @@ class ComputerVirtualMachine extends CommonDBChild {
    /**
     * Find a virtual machine by uuid
     *
-    * @param fields array of virtualmachine fields
+    * @param array $fields  Array of virtualmachine fields
     *
-    * @return the ID of the computer that have this uuid or false otherwise
+    * @return integer|boolean ID of the computer that have this uuid or false otherwise
    **/
    static function findVirtualMachine($fields = []) {
       global $DB;
@@ -476,17 +475,212 @@ class ComputerVirtualMachine extends CommonDBChild {
          return false;
       }
 
-      $query = "SELECT `id`
-                FROM `glpi_computers`
-                WHERE LOWER(`uuid`) ".self::getUUIDRestrictRequest($fields['uuid']);
-      $result = $DB->query($query);
+      $iterator = $DB->request([
+         'SELECT' => 'id',
+         'FROM'   => 'glpi_computers',
+         'WHERE'  => [
+            'RAW' => [
+               'LOWER(uuid)'  => self::getUUIDRestrictCriteria($fields['uuid'])
+            ]
+         ]
+      ]);
 
       //Virtual machine found, return ID
-      if ($DB->numrows($result)) {
-         return $DB->result($result, 0, 'id');
+      if (count($iterator) == 1) {
+         $result = $iterator->next();
+         return $result['id'];
+      } else if (count($iterator) > 1) {
+         Toolbox::logWarning(
+            sprintf(
+               'findVirtualMachine expects to get one result, %1$s found!',
+               count($iterator)
+            )
+         );
       }
 
       return false;
    }
 
+   function rawSearchOptions() {
+
+      $tab = [];
+
+      $tab[] = [
+         'id'                 => 'common',
+         'name'               => __('Characteristics')
+      ];
+
+      $tab[] = [
+         'id'                 => '1',
+         'table'              => $this->getTable(),
+         'field'              => 'name',
+         'name'               => __('Name'),
+         'datatype'           => 'itemlink',
+         'massiveaction'      => false,
+         'autocomplete'       => true,
+      ];
+
+      $tab[] = [
+         'id'                 => '2',
+         'table'              => $this->getTable(),
+         'field'              => 'uuid',
+         'name'               => __('UUID'),
+         'datatype'           => 'string',
+         'massiveaction'      => false,
+         'autocomplete'       => true,
+      ];
+
+      $tab[] = [
+         'id'                 => '3',
+         'table'              => $this->getTable(),
+         'field'              => 'ram',
+         'name'               => _n('Memory', 'Memories', 1),
+         'datatype'           => 'string',
+         'massiveaction'      => false,
+         'autocomplete'       => true,
+      ];
+
+      $tab[] = [
+         'id'                 => '4',
+         'table'              => $this->getTable(),
+         'field'              => 'vcpu',
+         'name'               => __('processor number'),
+         'datatype'           => 'string',
+         'massiveaction'      => false,
+         'autocomplete'       => true,
+      ];
+
+      return $tab;
+   }
+
+   public static function rawSearchOptionsToAdd($itemtype) {
+      $tab = [];
+
+      $name = _n('Virtual machine', 'Virtual machines', Session::getPluralNumber());
+      $tab[] = [
+         'id'                 => 'virtualmachine',
+         'name'               => $name
+      ];
+
+      $tab[] = [
+         'id'                 => '160',
+         'table'              => self::getTable(),
+         'field'              => 'name',
+         'name'               => __('Name'),
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'datatype'           => 'dropdown',
+         'joinparams'         => [
+            'jointype'           => 'child'
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '161',
+         'table'              => 'glpi_virtualmachinestates',
+         'field'              => 'name',
+         'name'               => __('State'),
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'datatype'           => 'dropdown',
+         'joinparams'         => [
+            'beforejoin'         => [
+               'table'              => self::getTable(),
+               'joinparams'         => [
+                  'jointype'           => 'child'
+               ]
+            ]
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '162',
+         'table'              => 'glpi_virtualmachinesystems',
+         'field'              => 'name',
+         'name'               => VirtualMachineSystem::getTypeName(1),
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'datatype'           => 'dropdown',
+         'joinparams'         => [
+            'beforejoin'         => [
+               'table'              => self::getTable(),
+               'joinparams'         => [
+                  'jointype'           => 'child'
+               ]
+            ]
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '163',
+         'table'              => 'glpi_virtualmachinetypes',
+         'field'              => 'name',
+         'name'               => VirtualMachineType::getTypeName(1),
+         'datatype'           => 'dropdown',
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'joinparams'         => [
+            'beforejoin'         => [
+               'table'              => self::getTable(),
+               'joinparams'         => [
+                  'jointype'           => 'child'
+               ]
+            ]
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '164',
+         'table'              => self::getTable(),
+         'field'              => 'vcpu',
+         'name'               => __('processor number'),
+         'datatype'           => 'number',
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'joinparams'         => [
+            'jointype'           => 'child'
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '165',
+         'table'              => self::getTable(),
+         'field'              => 'ram',
+         'name'               => _n('Memory', 'Memories', 1),
+         'datatype'           => 'string',
+         'unit'               => 'auto',
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'joinparams'         => [
+            'jointype'           => 'child'
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '166',
+         'table'              => self::getTable(),
+         'field'              => 'uuid',
+         'name'               => __('UUID'),
+         'forcegroupby'       => true,
+         'massiveaction'      => false,
+         'joinparams'         => [
+            'jointype'           => 'child'
+         ]
+      ];
+
+      $tab[] = [
+         'id'                 => '179',
+         'table'              => self::getTable(),
+         'field'              => 'comment',
+         'name'               => __('Virtual machine Comment'),
+         'forcegroupby'       => true,
+         'datatype'           => 'string',
+         'massiveaction'      => false,
+         'joinparams'         => [
+            'jointype'           => 'child'
+         ]
+      ];
+
+      return $tab;
+   }
 }
