@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -207,9 +207,10 @@ class Provider extends CommonGLPI {
       $DBread = DBConnection::getReadConnection();
 
       $default_params = [
-         'label'         => "",
-         'icon'          => Ticket::getIcon(),
-         'apply_filters' => [],
+         'label'                 => "",
+         'icon'                  => Ticket::getIcon(),
+         'apply_filters'         => [],
+         'validation_check_user' => false,
       ];
       $params = array_merge($default_params, $params);
 
@@ -244,6 +245,7 @@ class Provider extends CommonGLPI {
       switch ($case) {
          case 'notold':
             $search_criteria = [$notold];
+            $params['label']  = _x('status', 'Not solved');
             $query_criteria['WHERE']+= [
                "$table.status" => Ticket::getNotSolvedStatusArray(),
             ];
@@ -292,19 +294,32 @@ class Provider extends CommonGLPI {
 
          case 'waiting_validation':
             $params['icon']  = "far fa-eye";
-            $params['label'] = __("Tickets waiting your validation");
+            $params['label'] = __("Tickets waiting for validation");
             $search_criteria = [
                [
                   'field'      => 55,
                   'searchtype' => 'equals',
                   'value'      => CommonITILValidation::WAITING,
-               ],  [
+               ]
+            ];
+
+            if ($params['validation_check_user']) {
+               $search_criteria[] = [
                   'link'       => 'AND',
                   'field'      => 59,
                   'searchtype' => 'equals',
                   'value'      => Session::getLoginUserID(),
-               ]
+               ];
+            }
+
+            $where = [
+               'glpi_ticketvalidations.status' => CommonITILValidation::WAITING,
             ];
+
+            if ($params['validation_check_user']) {
+               $where['glpi_ticketvalidations.users_id_validate'] = Session::getLoginUserID();
+            }
+
             $query_criteria = array_merge_recursive($query_criteria, [
                'LEFT JOIN' => [
                   'glpi_ticketvalidations' => [
@@ -314,10 +329,7 @@ class Provider extends CommonGLPI {
                      ]
                   ]
                ],
-               'WHERE' => [
-                  'glpi_ticketvalidations.status'            => CommonITILValidation::WAITING,
-                  'glpi_ticketvalidations.users_id_validate' => Session::getLoginUserID()
-               ]
+               'WHERE' => $where,
             ]);
             break;
 
@@ -616,10 +628,13 @@ class Provider extends CommonGLPI {
       $criteria = array_merge_recursive(
          [
             'SELECT' => [
-               'COUNT' => "$t_table.id as nb_tickets",
+               'COUNT DISTINCT' => "$t_table.id as nb_tickets",
                new QueryExpression("DATE_FORMAT(".$DB->quoteName("date").", '%Y-%m') AS ticket_month")
             ],
             'FROM'    => $t_table,
+            'WHERE'    => [
+               "$t_table.is_deleted" => 0,
+            ] + getEntitiesRestrictCriteria($t_table),
             'GROUPBY' => 'ticket_month',
             'ORDER'   => 'ticket_month ASC'
          ],
@@ -1051,7 +1066,7 @@ class Provider extends CommonGLPI {
       $criteria = array_merge_recursive(
          [
             'SELECT' => array_merge([
-               'COUNT' => "$t_table.id AS nb_tickets",
+               'COUNT DISTINCT' => "$t_table.id AS nb_tickets",
                "$ug_table.id as actor_id",
             ], $n_fields),
             'FROM' => $t_table,
@@ -1213,6 +1228,7 @@ class Provider extends CommonGLPI {
       $waiting    = self::nbTicketsGeneric('waiting', $params);
       $tovalidate = self::nbTicketsGeneric('waiting_validation', $params);
       $closed     = self::nbTicketsGeneric('closed', $params);
+      $solved     = self::nbTicketsGeneric('solved', $params);
 
       return [
          'data'  => [
@@ -1236,6 +1252,11 @@ class Provider extends CommonGLPI {
                'label'  => __("To validate"),
                'url'    => $tovalidate['url'],
                'color'  => '#266ae9',
+            ], [
+               'number' => $solved['number'],
+               'label'  => __("Solved"),
+               'url'    => $solved['url'],
+               'color'  => '#edc949',
             ], [
                'number' => $closed['number'],
                'label'  => __("Closed"),
@@ -1521,20 +1542,20 @@ class Provider extends CommonGLPI {
             $itemtype  = getItemTypeForTable($table);
             $main_item = getItemForItemtype($itemtype);
             $userlink  = $main_item->userlinkclass;
-            $gl_table  = $userlink::getTable();
+            $ul_table  = $userlink::getTable();
             $fk        = $main_item->getForeignKeyField();
 
             $join += [
-               "$gl_table as gl" => [
+               "$ul_table as ul" => [
                   'ON' => [
-                     'gl'   => $fk,
+                     'ul'   => $fk,
                      $table => 'id',
                   ]
                ]
             ];
             $where += [
-               "gl.type"     => \CommonITILActor::ASSIGN,
-               "gl.users_id" => (int) $apply_filters['user_tech']
+               "ul.type"     => \CommonITILActor::ASSIGN,
+               "ul.users_id" => (int) $apply_filters['user_tech']
             ];
          }
       }
