@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2018 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -223,7 +223,7 @@ function countElementsInTableForEntity($table, $entity, $condition = [], $recurs
 
 
 /**
- * Get datas from a table in an array :
+ * Get data from a table in an array :
  * CAUTION TO USE ONLY FOR SMALL TABLES OR USING A STRICT CONDITION
  *
  * @param string  $table     table name
@@ -232,12 +232,31 @@ function countElementsInTableForEntity($table, $entity, $condition = [], $recurs
  * @param string  $order     result order (default '')
  *
  * @return array containing all the datas
+ *
+ * @deprecated 9.5.0
 **/
 function getAllDatasFromTable($table, $condition = [], $usecache = false, $order = '') {
-   $dbu = new DbUtils();
-   return $dbu->getAllDataFromTable($table, $condition, $usecache, $order);
+   Toolbox::deprecated('Use getAllDataFromTable()');
+   return getAllDataFromTable($table, $condition, $usecache, $order);
 }
 
+/**
+ * Get data from a table in an array :
+ * CAUTION TO USE ONLY FOR SMALL TABLES OR USING A STRICT CONDITION
+ *
+ * @param string  $table    table name
+ * @param array   $criteria condition to use (default [])
+ * @param boolean $usecache Use cache (false by default)
+ * @param string  $order    result order (default '')
+ *
+ * @return array containing all the datas
+ *
+ * @since 9.5.0
+**/
+function getAllDataFromTable($table, $criteria = [], $usecache = false, $order = '') {
+   $dbu = new DbUtils();
+   return $dbu->getAllDataFromTable($table, $criteria, $usecache, $order);
+}
 /**
  * Get the Name of the element of a Dropdown Tree table
  *
@@ -386,6 +405,8 @@ function contructListFromTree($tree, $parent = 0) {
  * @param $reallink  string   real field to link ($table.id if not set) (default ='')
  *
  * @return string the query
+ *
+ * @deprecated 9.5.0
 **/
 function getRealQueryForTreeItem($table, $IDf, $reallink = "") {
    $dbu = new DbUtils();
@@ -406,42 +427,6 @@ function regenerateTreeCompleteName($table) {
 }
 
 
-/**
- * Get the ID of the next Item
- *
- * @deprecated 9.4
- *
- * @param string  $table         table to search next item
- * @param integer $ID            current ID
- * @param string  $condition     condition to add to the search (default ='')
- * @param string  $nextprev_item field used to sort (default ='name')
- *
- * @return integer the next ID, -1 if not exist
- */
-function getNextItem($table, $ID, $condition = "", $nextprev_item = "name") {
-   $dbu = new DbUtils();
-   return $dbu->getNextItem($table, $ID, $condition, $nextprev_item);
-}
-
-
-/**
- * Get the ID of the previous Item
- *
- * @deprecated 9.4
- *
- * @param string  $table         table to search next item
- * @param integer $ID            current ID
- * @param string  $condition     condition to add to the search (default ='')
- * @param string  $nextprev_item field used to sort (default ='name')
- *
- * @return integer the previous ID, -1 if not exist
- */
-function getPreviousItem($table, $ID, $condition = "", $nextprev_item = "name") {
-   $dbu = new DbUtils();
-   return $dbu->getPreviousItem($table, $ID, $condition, $nextprev_item);
-}
-
-
 /**
  * Format a user name
  *
@@ -517,31 +502,14 @@ function closeDBConnections() {
    return $dbu->closeDBConnections();
 }
 
-
 /**
  * Add dates for request
  *
- * @deprecated 9.4
+ * @param string $field  table.field to request
+ * @param string $begin  begin date
+ * @param string $end    end date
  *
- * @param string $field table.field to request
- * @param string $begin begin date
- * @param string $end   end date
- *
- * @return string SQL
- */
-function getDateRequest($field, $begin, $end) {
-   $dbu = new DbUtils();
-   return $dbu->getDateRequest($field, $begin, $end);
-}
-
-/**
- * Add dates for request
- *
- * @param $field        table.field to request
- * @param $begin  date  begin date
- * @param $end    date  end date
- *
- * @return sql
+ * @return string
 **/
 function getDateCriteria($field, $begin, $end) {
    $dbu = new DbUtils();
@@ -651,11 +619,18 @@ function getEntitiesRestrictRequest($separator = "AND", $table = "", $field = ""
 function getEntitiesRestrictCriteria($table = '', $field = '', $value = '',
                                      $is_recursive = false, $complete_request = false) {
    $dbu = new DbUtils();
-   return $dbu->getEntitiesRestrictCriteria(
+   $res = $dbu->getEntitiesRestrictCriteria(
       $table,
       $field,
       $value,
       $is_recursive,
       $complete_request
    );
+
+   // Add another layer to the array to prevent losing duplicates keys if the
+   // result of the function is merged with another array
+   if (count($res)) {
+      $res = [crc32(serialize($res)) => $res];
+   }
+   return $res;
 }
