@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2017 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -30,10 +30,6 @@
  * ---------------------------------------------------------------------
  */
 
-/** @file
-* @brief
-*/
-
 if (!defined('GLPI_ROOT')) {
    die("Sorry. You can't access this file directly");
 }
@@ -57,29 +53,22 @@ class DisplayPreference extends CommonDBTM {
 
 
 
-   /**
-    * @see CommonDBTM::prepareInputForAdd()
-   **/
    function prepareInputForAdd($input) {
       global $DB;
 
-      $query = "SELECT MAX(`rank`)
-                FROM `".$this->getTable()."`
-                WHERE `itemtype` = '".$input["itemtype"]."'
-                      AND `users_id` = '".$input["users_id"]."'";
-      $result = $DB->query($query);
-
-      $input["rank"] = $DB->result($result, 0, 0)+1;
-
+      $result = $DB->request([
+         'SELECT' => ['MAX' => 'rank AS maxrank'],
+         'FROM'   => $this->getTable(),
+         'WHERE'  => [
+            'itemtype'  => $input['itemtype'],
+            'users_id'  => $input['users_id']
+         ]
+      ])->next();
+      $input['rank'] = $result['maxrank'] + 1;
       return $input;
    }
 
 
-   /**
-    * @since version 0.85
-    *
-    * @see CommonDBTM::processMassiveActionsForOneItemtype()
-   **/
    static function processMassiveActionsForOneItemtype(MassiveAction $ma, CommonDBTM $item,
                                                        array $ids) {
 
@@ -115,23 +104,30 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Get display preference for a user for an itemtype
     *
-    * @param $itemtype  itemtype
-    * @param $user_id   user ID
+    * @param string  $itemtype  itemtype
+    * @param integer $user_id   user ID
+    *
+    * @return array
    **/
    static function getForTypeUser($itemtype, $user_id) {
       global $DB;
 
-      $query = "SELECT *
-                FROM `glpi_displaypreferences`
-                WHERE `itemtype` = '$itemtype'
-                      AND (`users_id` = '$user_id' OR `users_id` = '0')
-                ORDER BY `users_id`, `rank`";
-      $result = $DB->query($query);
+      $iterator = $DB->request([
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'itemtype'  => $itemtype,
+            'OR'        => [
+               ['users_id' => $user_id],
+               ['users_id' => 0]
+            ]
+         ],
+         'ORDER'  => ['users_id', 'rank']
+      ]);
 
       $default_prefs = [];
       $user_prefs = [];
 
-      while ($data = $DB->fetch_assoc($result)) {
+      while ($data = $iterator->next()) {
          if ($data["users_id"] != 0) {
             $user_prefs[] = $data["num"];
          } else {
@@ -155,14 +151,16 @@ class DisplayPreference extends CommonDBTM {
          return false;
       }
 
-      $query = "SELECT *
-                FROM `".$this->getTable()."`
-                WHERE `itemtype` = '".$input["itemtype"]."'
-                      AND `users_id` = '0'";
-      $result = $DB->query($query);
+      $iterator = $DB->request([
+         'FROM'   => self::getTable(),
+         'WHERE'  => [
+            'itemtype'  => $input['itemtype'],
+            'users_id'  => 0
+         ]
+      ]);
 
-      if ($DB->numrows($result)) {
-         while ($data = $DB->fetch_assoc($result)) {
+      if (count($iterator)) {
+         while ($data = $iterator->next()) {
             unset($data["id"]);
             $data["users_id"] = $input["users_id"];
             $this->fields     = $data;
@@ -197,64 +195,74 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Order to move an item
     *
-    * @param $input  array parameter (id,itemtype,users_id)
-    * @param $action       up or down
+    * @param array  $input  array parameter (id,itemtype,users_id)
+    * @param string $action       up or down
    **/
    function orderItem(array $input, $action) {
       global $DB;
 
       // Get current item
-      $query = "SELECT `rank`
-                FROM `".$this->getTable()."`
-                WHERE `id` = '".$input['id']."'";
-      $result = $DB->query($query);
-      $rank1  = $DB->result($result, 0, 0);
+      $result = $DB->request([
+         'SELECT' => 'rank',
+         'FROM'   => $this->getTable(),
+         'WHERE'  => ['id' => $input['id']]
+      ])->next();
+      $rank1  = $result['rank'];
 
       // Get previous or next item
-      $query = "SELECT `id`, `rank`
-                FROM `".$this->getTable()."`
-                WHERE `itemtype` = '".$input['itemtype']."'
-                      AND `users_id` = '".$input["users_id"]."'";
-
+      $where = [];
+      $order = 'rank ';
       switch ($action) {
          case "up" :
-            $query .= " AND `rank` < '$rank1'
-                      ORDER BY `rank` DESC";
+            $where['rank'] = ['<', $rank1];
+            $order .= 'DESC';
             break;
 
          case "down" :
-            $query .= " AND `rank` > '$rank1'
-                      ORDER BY `rank` ASC";
+            $where['rank'] = ['>', $rank1];
+            $order .= 'ASC';
             break;
 
          default :
             return false;
       }
 
-      $result = $DB->query($query);
-      $rank2  = $DB->result($result, 0, "rank");
-      $ID2    = $DB->result($result, 0, "id");
+      $result = $DB->request([
+         'SELECT' => ['id', 'rank'],
+         'FROM'   => $this->getTable(),
+         'WHERE'  => [
+            'itemtype'  => $input['itemtype'],
+            'users_id'  => $input["users_id"]
+         ] + $where,
+         'ORDER'  => $order,
+         'LIMIT'  => 1
+      ])->next();
+
+      $rank2  = $result['rank'];
+      $ID2    = $result['id'];
 
       // Update items
-      $query = "UPDATE `".$this->getTable()."`
-                SET `rank` = '$rank2'
-                WHERE `id` = '".$input['id']."'";
-      $DB->query($query);
+      $DB->update(
+         $this->getTable(),
+         ['rank' => $rank2],
+         ['id' => $input['id']]
+      );
 
-      $query = "UPDATE `".$this->getTable()."`
-                SET `rank` = '$rank1'
-                WHERE `id` = '$ID2'";
-      $DB->query($query);
+      $DB->update(
+         $this->getTable(),
+         ['rank' => $rank1],
+         ['id' => $ID2]
+      );
    }
 
 
    /**
     * Print the search config form
     *
-    * @param $target    form target
-    * @param $itemtype  item type
+    * @param string $target    form target
+    * @param string $itemtype  item type
     *
-    * @return nothing
+    * @return void|boolean (display) Returns false if there is a rights error.
    **/
    function showFormPerso($target, $itemtype) {
       global $CFG_GLPI, $DB;
@@ -273,14 +281,15 @@ class DisplayPreference extends CommonDBTM {
 
       echo "<div class='center' id='tabsbody' >";
       // Defined items
-      $query = "SELECT *
-                FROM `".$this->getTable()."`
-                WHERE `itemtype` = '$itemtype'
-                      AND `users_id` = '$IDuser'
-                ORDER BY `rank`";
-      $result  = $DB->query($query);
-      $numrows = 0;
-      $numrows = $DB->numrows($result);
+      $iterator = $DB->request([
+         'FROM'   => $this->getTable(),
+         'WHERE'  => [
+            'itemtype'  => $itemtype,
+            'users_id'  => $IDuser
+         ],
+         'ORDER'  => 'rank'
+      ]);
+      $numrows = count($iterator);
 
       if ($numrows == 0) {
          Session::checkRight(self::$rightname, self::PERSONAL);
@@ -356,7 +365,7 @@ class DisplayPreference extends CommonDBTM {
 
          $i = 0;
          if ($numrows) {
-            while ($data = $DB->fetch_assoc($result)) {
+            while ($data = $iterator->next()) {
                if (($data["num"] !=1) && isset($searchopt[$data["num"]])) {
                   echo "<tr class='tab_bg_2'>";
                   echo "<td class='center' width='50%' >";
@@ -394,16 +403,20 @@ class DisplayPreference extends CommonDBTM {
                      echo "<td>&nbsp;</td>";
                   }
 
-                  echo "<td class='center middle'>";
-                  echo "<form method='post' action='$target'>";
-                  echo "<input type='hidden' name='id' value='".$data["id"]."'>";
-                  echo "<input type='hidden' name='users_id' value='$IDuser'>";
-                  echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                  echo "<button type='submit' name='purge'".
-                         " title=\""._sx('button', 'Delete permanently')."\"".
-                         " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
-                  Html::closeForm();
-                  echo "</td>\n";
+                  if (!isset($searchopt[$data["num"]]["noremove"]) || $searchopt[$data["num"]]["noremove"] !== true) {
+                     echo "<td class='center middle'>";
+                     echo "<form method='post' action='$target'>";
+                     echo "<input type='hidden' name='id' value='".$data["id"]."'>";
+                     echo "<input type='hidden' name='users_id' value='$IDuser'>";
+                     echo "<input type='hidden' name='itemtype' value='$itemtype'>";
+                     echo "<button type='submit' name='purge'".
+                           " title=\""._sx('button', 'Delete permanently')."\"".
+                           " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
+                     Html::closeForm();
+                     echo "</td>\n";
+                  } else {
+                     echo "<td>&nbsp;</td>\n";
+                  }
                   echo "</tr>";
                   $i++;
                }
@@ -418,10 +431,10 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Print the search config form
     *
-    * @param $target    form target
-    * @param $itemtype  item type
+    * @param string $target    form target
+    * @param string $itemtype  item type
     *
-    * @return nothing
+    * @return void|boolean (display) Returns false if there is a rights error.
    **/
    function showFormGlobal($target, $itemtype) {
       global $CFG_GLPI, $DB;
@@ -441,14 +454,15 @@ class DisplayPreference extends CommonDBTM {
 
       echo "<div class='center' id='tabsbody' >";
       // Defined items
-      $query = "SELECT *
-                FROM `".$this->getTable()."`
-                WHERE `itemtype` = '$itemtype'
-                      AND `users_id` = '$IDuser'
-                ORDER BY `rank`";
-
-      $result  = $DB->query($query);
-      $numrows = $DB->numrows($result);
+      $iterator = $DB->request([
+         'FROM'   => $this->getTable(),
+         'WHERE'  => [
+            'itemtype'  => $itemtype,
+            'users_id'  => $IDuser
+         ],
+         'ORDER'  => 'rank'
+      ]);
+      $numrows = count($iterator);
 
       echo "<table class='tab_cadre_fixehov'><tr><th colspan='4'>";
       echo __('Select default items to show')."</th></tr>\n";
@@ -507,7 +521,7 @@ class DisplayPreference extends CommonDBTM {
       $i = 0;
 
       if ($numrows) {
-         while ($data=$DB->fetch_assoc($result)) {
+         while ($data = $iterator->next()) {
 
             if (($data["num"] != 1)
                 && isset($searchopt[$data["num"]])) {
@@ -549,16 +563,20 @@ class DisplayPreference extends CommonDBTM {
                      echo "<td>&nbsp;</td>\n";
                   }
 
-                  echo "<td class='center middle'>";
-                  echo "<form method='post' action='$target'>";
-                  echo "<input type='hidden' name='id' value='".$data["id"]."'>";
-                  echo "<input type='hidden' name='users_id' value='$IDuser'>";
-                  echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                  echo "<button type='submit' name='purge'".
-                         " title=\""._sx('button', 'Delete permanently')."\"".
-                         " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
-                  Html::closeForm();
-                  echo "</td>\n";
+                  if (!isset($searchopt[$data["num"]]["noremove"]) || $searchopt[$data["num"]]["noremove"] !== true) {
+                     echo "<td class='center middle'>";
+                     echo "<form method='post' action='$target'>";
+                     echo "<input type='hidden' name='id' value='".$data["id"]."'>";
+                     echo "<input type='hidden' name='users_id' value='$IDuser'>";
+                     echo "<input type='hidden' name='itemtype' value='$itemtype'>";
+                     echo "<button type='submit' name='purge'".
+                           " title=\""._sx('button', 'Delete permanently')."\"".
+                           " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
+                     Html::closeForm();
+                     echo "</td>\n";
+                  } else {
+                     echo "<td>&nbsp;</td>\n";
+                  }
                }
 
                echo "</tr>";
@@ -581,14 +599,17 @@ class DisplayPreference extends CommonDBTM {
 
       $url = Toolbox::getItemTypeFormURL(__CLASS__);
 
-      $query = "SELECT `itemtype`,
-                       COUNT(*) AS nb
-                FROM `glpi_displaypreferences`
-                WHERE `users_id` = '$users_id'
-                GROUP BY `itemtype`";
+      $iterator = $DB->request([
+         'SELECT'  => ['itemtype'],
+         'COUNT'   => 'nb',
+         'FROM'    => self::getTable(),
+         'WHERE'   => [
+            'users_id'  => $users_id
+         ],
+         'GROUPBY' => 'itemtype'
+      ]);
 
-      $req = $DB->request($query);
-      if ($req->numrows() > 0) {
+      if (count($iterator) > 0) {
          $rand = mt_rand();
          echo "<div class='spaced'>";
          Html::openMassiveActionsForm('mass'.__CLASS__.$rand);
@@ -606,10 +627,10 @@ class DisplayPreference extends CommonDBTM {
          echo "<table class='tab_cadre_fixe'>";
          echo "<tr>";
          echo "<th width='10'>";
-         Html::checkAllAsCheckbox('mass'.__CLASS__.$rand);
+         echo Html::getCheckAllAsCheckbox('mass'.__CLASS__.$rand);
          echo "</th>";
-         echo "<th colspan='2'>".__('Type')."</th></tr>";
-         foreach ($req as $data) {
+         echo "<th colspan='2'>"._n('Type', 'Types', 1)."</th></tr>";
+         while ($data = $iterator->next()) {
             echo "<tr class='tab_bg_1'><td width='10'>";
             Html::showMassiveActionCheckBox(__CLASS__, $data["itemtype"]);
             echo "</td>";
@@ -638,7 +659,7 @@ class DisplayPreference extends CommonDBTM {
    /**
     * For tab management : force isNewItem
     *
-    * @since version 0.83
+    * @since 0.83
    **/
    function isNewItem() {
       return false;
@@ -685,12 +706,12 @@ class DisplayPreference extends CommonDBTM {
          case __CLASS__ :
             switch ($tabnum) {
                case 1 :
-                  $item->showFormGlobal($_GET['_target'], $_GET["displaytype"]);
+                  $item->showFormGlobal(Toolbox::cleanTarget($_GET['_target']), $_GET["displaytype"]);
                   return true;
 
                case 2 :
                   Session::checkRight(self::$rightname, self::PERSONAL);
-                  $item->showFormPerso($_GET['_target'], $_GET["displaytype"]);
+                  $item->showFormPerso(Toolbox::cleanTarget($_GET['_target']), $_GET["displaytype"]);
                   return true;
             }
       }
@@ -698,11 +719,6 @@ class DisplayPreference extends CommonDBTM {
    }
 
 
-   /**
-    * @since version 0.85
-    *
-    * @see commonDBTM::getRights()
-   **/
    function getRights($interface = 'central') {
 
       //TRANS: short for : Search result user display
