@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -185,7 +185,7 @@ class Document_Item extends CommonDBRelation{
 
    function post_addItem() {
 
-      if ($this->fields['itemtype'] == 'Ticket') {
+      if ($this->fields['itemtype'] == 'Ticket' && ($this->input['_do_update_ticket'] ?? true)) {
          $ticket = new Ticket();
          $input  = [
             'id'              => $this->fields['items_id'],
@@ -426,13 +426,16 @@ class Document_Item extends CommonDBRelation{
             }
 
             while ($data = $iterator->next()) {
+               $linkname_extra = "";
                if ($item instanceof ITILFollowup || $item instanceof ITILSolution) {
+                  $linkname_extra = "(" . $item::getTypeName(1) . ")";
                   $itemtype = $data['itemtype'];
                   $item = new $itemtype();
                   $item->getFromDB($data['items_id']);
                   $data['id'] = $item->fields['id'];
                   $data['entity'] = $item->fields['entities_id'];
                } else if ($item instanceof CommonITILTask) {
+                  $linkname_extra = "(" . CommonITILTask::getTypeName(1) . ")";
                   $itemtype = $item->getItilObjectItemType();
                   $item = new $itemtype();
                   $item->getFromDB($data[$item->getForeignKeyField()]);
@@ -466,8 +469,9 @@ class Document_Item extends CommonDBRelation{
                      $linkname = $tmpitem->getLink();
                   }
                }
+
                $link     = $itemtype::getFormURLWithID($data['id']);
-               $name = "<a href=\"".$link."\">".$linkname."</a>";
+               $name = "<a href='$link'>$linkname $linkname_extra</a>";
 
                echo "<tr class='tab_bg_1'>";
 
@@ -969,7 +973,7 @@ class Document_Item extends CommonDBRelation{
     *
     * @param integer $items_id Object id to restrict on
     * @param string  $itemtype Type for items to retrieve
-    * @param boolean $noent    Flag to not compute enitty informations (see Document_Item::getTypeItemsQueryParams)
+    * @param boolean $noent    Flag to not compute enitty information (see Document_Item::getTypeItemsQueryParams)
     * @param array   $where    Inital WHERE clause. Defaults to []
     *
     * @return DBmysqlIterator
@@ -1011,7 +1015,7 @@ class Document_Item extends CommonDBRelation{
     * @since 9.3.1
     *
     * @param CommonDBTM $item  Item instance
-    * @param boolean    $noent Flag to not compute entity informations (see Document_Item::getTypeItemsQueryParams)
+    * @param boolean    $noent Flag to not compute entity information (see Document_Item::getTypeItemsQueryParams)
     *
     * @return array
     */
