@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -784,7 +784,11 @@ class Infocom extends CommonDBChild {
 
       $elapsed_years = $now->format('Y') - $usedate->format('Y');
 
-      $annuity = $value * (1 / $duration);
+      $annuity = 0;
+      if ($duration) {
+         $annuity = $value * (1 / $duration);
+      }
+
       $years = [];
       for ($i = 0; $i <= $elapsed_years; ++$i) {
          $begin_value      = $value;
@@ -1320,13 +1324,6 @@ class Infocom extends CommonDBChild {
       $beforejoin        = [];
 
       switch ($itemtype) {
-         case 'Software' :
-            // Return the infocom linked to the license, not the template linked to the software
-            $beforejoin        = ['table'      => 'glpi_softwarelicenses',
-                                       'joinparams' => ['jointype' => 'child']];
-            $specific_itemtype = 'SoftwareLicense';
-            break;
-
          case 'CartridgeItem' :
             // Return the infocom linked to the license, not the template linked to the software
             $beforejoin        = ['table'      => 'glpi_cartridges',
@@ -1613,6 +1610,7 @@ class Infocom extends CommonDBChild {
          'field'              => 'decommission_date',
          'name'               => __('Decommission date'),
          'datatype'           => 'date',
+         'maybefuture'        => true,
          'forcegroupby'       => true,
          'joinparams'         => $joinparams
       ];
@@ -1695,6 +1693,7 @@ class Infocom extends CommonDBChild {
          'table'              => $this->getTable(),
          'field'              => 'decommission_date',
          'name'               => __('Decommission date'),
+         'maybefuture'        => true,
          'datatype'           => 'date',
          'forcegroupby'       => true
       ];
@@ -1940,10 +1939,11 @@ class Infocom extends CommonDBChild {
     * @param integer $addwarranty   period in months
     * @param integer $deletenotice  period in months of notice (default 0)
     * @param boolean $color         if show expire date in red color (false by default)
+    * @param boolean $auto_renew
     *
     * @return string expiration date
    **/
-   static function getWarrantyExpir($from, $addwarranty, $deletenotice = 0, $color = false) {
+   static function getWarrantyExpir($from, $addwarranty, $deletenotice = 0, $color = false, $auto_renew = false) {
 
       // Life warranty
       if (($addwarranty == -1)
@@ -1955,11 +1955,20 @@ class Infocom extends CommonDBChild {
          return "";
       }
 
-      $datetime = strtotime("$from+$addwarranty month -$deletenotice month");
-      if ($color && ($datetime < time())) {
-         return "<span class='red'>".Html::convDate(date("Y-m-d", $datetime))."</span>";
+      $timestamp = strtotime("$from+$addwarranty month -$deletenotice month");
+
+      if ($auto_renew && $addwarranty > 0) {
+         while ($timestamp < time()) {
+            $datetime = new DateTime();
+            $datetime->setTimestamp($timestamp);
+            $timestamp = strtotime($datetime->format("Y-m-d H:i:s") . "+$addwarranty month");
+         }
       }
-      return Html::convDate(date("Y-m-d", $datetime));
+
+      if ($color && ($timestamp < time())) {
+         return "<span class='red'>".Html::convDate(date("Y-m-d", $timestamp))."</span>";
+      }
+      return Html::convDate(date("Y-m-d", $timestamp));
    }
 
 
