@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -126,15 +126,15 @@ class View extends CommonGLPI {
 
 
    /**
-    * Check current reigstration status and display warning messages
+    * Check current registration status and display warning messages
     *
     * @return bool
     */
-   static function checkRegister() {
+   static function checkRegistrationStatus() {
       global $CFG_GLPI;
 
       $messages   = [];
-      $registered = false;
+      $valid = false;
 
       if (!GLPINetwork::isServicesAvailable()) {
          array_push(
@@ -146,8 +146,10 @@ class View extends CommonGLPI {
             __("or please check later")
          );
       } else {
-         $registered = GLPINetwork::isRegistered();
-         if (!$registered) {
+         $registration_info = GLPINetwork::getRegistrationInformations();
+         if (!$registration_info['is_valid']) {
+            $valid = false;
+
             $config_url = $CFG_GLPI['root_doc']."/front/config.form.php?forcetab=".
                         urlencode('GLPINetwork$1');
 
@@ -159,6 +161,16 @@ class View extends CommonGLPI {
                __('and'). " ".
                "<a href='$config_url'>".__("fill your registration key in setup.")."</a>"
             );
+         } else if (!$registration_info['subscription']['is_running']) {
+            $valid = false;
+
+            array_push(
+               $messages,
+               sprintf(__('Your %1$s subscription has been terminated.'), 'GLPI Network'),
+               "<a href='".GLPI_NETWORK_SERVICES."'>".sprintf(__('Renew it on %1$s.'), 'GLPI Network')."</a> "
+            );
+         } else {
+            $valid = true;
          }
       }
 
@@ -170,7 +182,7 @@ class View extends CommonGLPI {
          echo "</div>";
       }
 
-      return $registered;
+      return $valid;
    }
 
 
@@ -195,7 +207,7 @@ class View extends CommonGLPI {
       $installed   = $plugin_inst->getList();
 
       $apiplugins  = [];
-      if (self::checkRegister()) {
+      if (self::checkRegistrationStatus()) {
          $api         = self::getAPI();
          $apiplugins  = $api->getAllPlugins($force_refresh);
       }
@@ -250,7 +262,7 @@ class View extends CommonGLPI {
       int $page = 1,
       string $sort = 'sort-alpha-asc'
    ) {
-      if (!self::checkRegister()) {
+      if (!self::checkRegistrationStatus()) {
          return;
       }
 
@@ -271,7 +283,7 @@ class View extends CommonGLPI {
       }
 
       header("X-GLPI-Marketplace-Total: $nb_plugins");
-      self::displayList($plugins, "discover", $only_lis, $nb_plugins, $sort);
+      self::displayList($plugins, "discover", $only_lis, $nb_plugins, $sort, $api->isListTruncated());
    }
 
 
@@ -311,12 +323,21 @@ class View extends CommonGLPI {
       string $tab = "",
       bool $only_lis = false,
       int $nb_plugins = 0,
-      string $sort = 'sort-alpha-asc'
+      string $sort = 'sort-alpha-asc',
+      bool $is_list_truncated = false
    ) {
       if (!self::canView()) {
          return false;
       }
 
+      $messages = '';
+      if ($is_list_truncated) {
+         $msg = count($plugins) === 0
+            ? sprintf(__('Unable to fetch plugin list due to %s services website unavailability. Please try again later.'), 'GLPI Network')
+            : sprintf(__('Plugin list may be truncated due to %s services website unavailability. Please try again later.'), 'GLPI Network');
+         $messages = '<li class="warning"><i class="fa fa-exclamation-triangle fa-3x"></i>'.$msg.'</li>';
+      }
+
       $plugins_li = "";
       foreach ($plugins as $plugin) {
          $plugin['description'] = self::getLocalizedDescription($plugin);
@@ -395,6 +416,7 @@ class View extends CommonGLPI {
                   </div>
                </div>
                <ul class='plugins'>
+                  {$messages}
                   {$plugins_li}
                </ul>
                $pagination
@@ -409,7 +431,7 @@ class View extends CommonGLPI {
 HTML;
          echo $marketplace;
       } else {
-         echo $plugins_li;
+         echo $messages . $plugins_li;
       }
 
       $js = <<<JS
@@ -440,7 +462,7 @@ JS;
    /**
     * Return HTML part for plugin card
     *
-    * @param array $plugin informations (title, description, etc) of the plugins
+    * @param array $plugin information (title, description, etc) of the plugins
     * @param string $tab current displayed tab (installed or discover)
     *
     * @return string the plugin card
@@ -597,7 +619,6 @@ HTML;
    static function getButtons(string $plugin_key = ""): string {
       global $CFG_GLPI, $PLUGIN_HOOKS;
 
-      $rand               = mt_rand();
       $plugin_inst        = new Plugin;
       $exists             = $plugin_inst->getFromDBbyDir($plugin_key);
       $is_installed       = $plugin_inst->isInstalled($plugin_key);
@@ -605,16 +626,18 @@ HTML;
       $mk_controller      = new Controller($plugin_key);
       $web_update_version = $mk_controller->checkUpdate($plugin_inst);
       $has_web_update     = $web_update_version !== false;
-      $has_loc_update     = $plugin_inst->isUpdatable($plugin_key);
+      $is_available       = $mk_controller->isAvailable();
       $can_be_overwritten = $mk_controller->canBeOverwritten();
       $can_be_downloaded  = $mk_controller->canBeDownloaded();
       $required_offers    = $mk_controller->getRequiredOffers();
       $can_be_updated     = $has_web_update && $can_be_overwritten;
-      $can_be_cleaned     = $exists && !$plugin_inst->isLoadable($plugin_key);
       $config_page        = $PLUGIN_HOOKS['config_page'][$plugin_key] ?? "";
+      $must_be_cleaned   = $exists && !$plugin_inst->isLoadable($plugin_key);
+      $has_local_install = $exists && !$must_be_cleaned && !$is_installed;
+      $has_local_update  = $exists && !$must_be_cleaned && $plugin_inst->isUpdatable($plugin_key);
 
       $error = "";
-      if ($exists) {
+      if ($exists && !$must_be_cleaned) {
          ob_start();
          $do_activate = $plugin_inst->checkVersions($plugin_key);
          if (!$do_activate) {
@@ -631,22 +654,35 @@ HTML;
             ob_end_clean();
          }
       }
+      $can_run_local_install = ($has_local_install || $has_local_update) && !strlen($error);
 
       $buttons = "";
 
       if (strlen($error)) {
+         $rand = mt_rand();
          $buttons .="<i class='fas fa-exclamation-triangle plugin-error' id='plugin-error-$rand'></i>";
          Html::showToolTip($error, [
             'applyto' => "plugin-error-$rand",
          ]);
       }
 
-      if ($can_be_cleaned) {
+      if ($must_be_cleaned) {
          $buttons .="<button class='modify_plugin'
                              data-action='clean_plugin'
                              title='".__s("Clean")."'>
             <i class='fas fa-broom'></i>
          </button>";
+      } else if (!$is_available) {
+         if (!$can_run_local_install) {
+            $rand = mt_rand();
+            $buttons .="<i class='fas fa-exclamation-triangle plugin-unavailable' id='plugin-tooltip-$rand'></i>";
+            Html::showToolTip(
+               __('This plugin is not available for your GLPI version.'),
+               [
+                  'applyto' => "plugin-tooltip-$rand",
+               ]
+            );
+         }
       } else if ((!$exists && !$mk_controller->hasWriteAccess())
          || ($has_web_update && !$can_be_overwritten && GLPI_MARKETPLACE_MANUAL_DOWNLOADS)) {
          $plugin_data = $mk_controller->getAPI()->getPlugin($plugin_key);
@@ -704,10 +740,10 @@ HTML;
             </a>";
       }
 
-      if ($exists && !$can_be_cleaned && !$is_installed && !strlen($error)) {
+      if ($can_run_local_install) {
          $title = __s("Install");
          $icon  = "fas fa-folder-plus";
-         if ($has_loc_update) {
+         if ($has_local_update) {
             $title = __s("Update");
             $icon  =  "far fa-caret-square-up";
          }
@@ -790,7 +826,7 @@ HTML;
 
 
    /**
-    * Return HTML part for Glpi Network informations for a given plugin
+    * Return HTML part for Glpi Network information for a given plugin
     * @param array $plugin data of the plugin.
     *                      if check agains plugin key if we need some subscription to use it
     * @return string the subscription information html
