@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2018 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -50,7 +50,7 @@ class Netpoint extends CommonDropdown {
    function getAdditionalFields() {
 
       return [['name'  => 'locations_id',
-                         'label' => __('Location'),
+                         'label' => Location::getTypeName(1),
                          'type'  => 'dropdownValue',
                          'list'  => true]];
    }
@@ -99,14 +99,14 @@ class Netpoint extends CommonDropdown {
    /**
     * Print out an HTML "<select>" for a dropdown with preselected value
     *
-    * @param $myname             the name of the HTML select
-    * @param $value              the preselected value we want (default 0)
-    * @param $locations_id       default location ID for search (default -1)
-    * @param $display_comment    display the comment near the dropdown (default 1)
-    * @param $entity_restrict    Restrict to a defined entity(default -1)
-    * @param $devtype            (default '')
+    * @param string  $myname             the name of the HTML select
+    * @param integer $value              the preselected value we want (default 0)
+    * @param integer $locations_id       default location ID for search (default -1)
+    * @param boolean $display_comment    display the comment near the dropdown (default 1)
+    * @param integer $entity_restrict    Restrict to a defined entity(default -1)
+    * @param string  $devtype            (default '')
     *
-    * @return nothing (display the select box)
+    * @return integer random part of elements id
    **/
    static function dropdownNetpoint($myname, $value = 0, $locations_id = -1, $display_comment = 1,
                                     $entity_restrict = -1, $devtype = '') {
@@ -150,8 +150,11 @@ class Netpoint extends CommonDropdown {
                                           $item->getFormURL());
 
          }
-         $paramscomment = ['value' => '__VALUE__',
-                                'table' => "glpi_netpoints"];
+         $paramscomment = [
+            'value'       => '__VALUE__',
+            'itemtype'    => Netpoint::getType(),
+            '_idor_token' => Session::getNewIDORToken("Netpoint")
+         ];
          echo Ajax::updateItemOnSelectEvent($field_id, $comment_id,
                                             $CFG_GLPI["root_doc"]."/ajax/comments.php",
                                             $paramscomment, false);
@@ -165,25 +168,25 @@ class Netpoint extends CommonDropdown {
     *
     * @param $input array of value to import (name, locations_id, entities_id)
     *
-    * @return the ID of the new (or -1 if not found)
+    * @return integer the ID of the new (or -1 if not found)
    **/
    function findID(array &$input) {
       global $DB;
 
       if (!empty($input["name"])) {
-         $query = "SELECT `id`
-                   FROM `".$this->getTable()."`
-                   WHERE `name` = '".$input["name"]."'
-                         AND `locations_id` = '".(isset($input["locations_id"])
-                                                      ?$input["locations_id"]:0)."'".
-                         getEntitiesRestrictRequest(' AND ', $this->getTable(), '',
-                                                    $input['entities_id'], $this->maybeRecursive());
+         $iterator = $DB->request([
+            'SELECT' => 'id',
+            'FROM'   => $this->getTable(),
+            'WHERE'  => [
+               'name'         => $input['name'],
+               'locations_id' => $input["locations_id"] ?? 0
+            ] + getEntitiesRestrictCriteria($this->getTable(), $input['entities_id'], $this->maybeRecursive())
+         ]);
 
          // Check twin :
-         if ($result_twin = $DB->query($query)) {
-            if ($DB->numrows($result_twin) > 0) {
-               return $DB->result($result_twin, 0, "id");
-            }
+         if (count($iterator)) {
+            $result = $iterator->next();
+            return $result['id'];
          }
       }
       return -1;
@@ -245,10 +248,10 @@ class Netpoint extends CommonDropdown {
     *
     * @param $item Location
     *
-    * @return Nothing (display)
+    * @return void
    **/
    static function showForLocation($item) {
-      global $DB, $CFG_GLPI;
+      global $DB;
 
       $ID       = $item->getField('id');
       $netpoint = new self();
@@ -399,7 +402,7 @@ class Netpoint extends CommonDropdown {
          return;
       }
 
-      $base->addHeader($column_name, __('Network outlet'), $super, $father);
+      $base->addHeader($column_name, _n('Network outlet', 'Network outlets', 1), $super, $father);
 
    }
 
