@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -360,17 +360,32 @@ class Plugin extends CommonDBTM {
          );
       }
 
-      $mofile = str_replace($locales_dir, GLPI_LOCAL_I18N_DIR . '/'.$plugin_key . '/', $mofile);
-      $phpfile = str_replace('.mo', '.php', $mofile);
+      $plugin_folders = is_dir(GLPI_LOCAL_I18N_DIR) ? scandir(GLPI_LOCAL_I18N_DIR) : [];
+      $plugin_folders = array_filter($plugin_folders, function($dir) use ($plugin_key) {
+         if (!is_dir(GLPI_LOCAL_I18N_DIR . "/$dir")) {
+            return false;
+         }
 
-      // Load local PHP file if it exists
-      if (file_exists($phpfile)) {
-         $TRANSLATE->addTranslationFile('phparray', $phpfile, $plugin_key, $coretrytoload);
-      }
+         if ($dir == $plugin_key) {
+            return true;
+         }
 
-      // Load local MO file if it exists -- keep last so it gets precedence
-      if (file_exists($mofile)) {
-         $TRANSLATE->addTranslationFile('gettext', $mofile, $plugin_key, $coretrytoload);
+         return Toolbox::startsWith($dir, $plugin_key . '_');
+      });
+
+      foreach ($plugin_folders as $plugin_folder) {
+         $mofile = GLPI_LOCAL_I18N_DIR . "/$plugin_folder/$coretrytoload.mo";
+         $phpfile = str_replace('.mo', '.php', $mofile);
+
+         // Load local PHP file if it exists
+         if (file_exists($phpfile)) {
+            $TRANSLATE->addTranslationFile('phparray', $phpfile, $plugin_key, $coretrytoload);
+         }
+
+         // Load local MO file if it exists -- keep last so it gets precedence
+         if (file_exists($mofile)) {
+            $TRANSLATE->addTranslationFile('gettext', $mofile, $plugin_key, $coretrytoload);
+         }
       }
    }
 
@@ -439,12 +454,12 @@ class Plugin extends CommonDBTM {
 
       if (empty($informations)) {
          if (!$is_already_known) {
-            // Plugin is not known and we are unable to load informations, we ignore it
+            // Plugin is not known and we are unable to load information, we ignore it
             return;
          }
 
          // Try to get information from a plugin that lists current name as its old name
-         // If something found, and not already registerd in DB,, base plugin informations on it
+         // If something found, and not already registerd in DB,, base plugin information on it
          // If nothing found, mark plugin as "To be cleaned"
          $new_specs = $this->getNewInfoAndDirBasedOnOldName($plugin_key);
          if (null !== $new_specs
@@ -454,12 +469,12 @@ class Plugin extends CommonDBTM {
          } else {
             trigger_error(
                sprintf(
-                  'Unable to load plugin "%s" informations.',
+                  'Unable to load plugin "%s" information.',
                   $plugin_key
                ),
                E_USER_WARNING
             );
-            // Plugin is known but we are unable to load informations, we ignore it
+            // Plugin is known but we are unable to load information, we ignore it
             return;
          }
       }
@@ -485,8 +500,8 @@ class Plugin extends CommonDBTM {
 
       if ($informations['version'] != $plugin->fields['version']
           || $plugin_key != $plugin->fields['directory']) {
-         // Plugin known version differs from informations or plugin has been renamed,
-         // update informations in database
+         // Plugin known version differs from information or plugin has been renamed,
+         // update information in database
          $input              = $informations;
          $input['id']        = $plugin->fields['id'];
          $input['directory'] = $plugin_key;
