@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2018 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -45,7 +45,8 @@ class ProblemTask extends CommonITILTask {
 
 
    static function canCreate() {
-      return Session::haveRight('problem', UPDATE);
+      return Session::haveRight('problem', UPDATE)
+          || Session::haveRight(self::$rightname, parent::ADDALLITEM);
    }
 
 
@@ -55,7 +56,8 @@ class ProblemTask extends CommonITILTask {
 
 
    static function canUpdate() {
-      return Session::haveRight('problem', UPDATE);
+      return Session::haveRight('problem', UPDATE)
+          || Session::haveRight(self::$rightname, parent::UPDATEALL);
    }
 
 
@@ -80,7 +82,7 @@ class ProblemTask extends CommonITILTask {
     * @return boolean
    **/
    function canViewItem() {
-      return parent::canReadITILItem();
+      return $this->canReadITILItem();
    }
 
 
@@ -90,14 +92,14 @@ class ProblemTask extends CommonITILTask {
     * @return boolean
    **/
    function canCreateItem() {
-
-      if (!parent::canReadITILItem()) {
+      if (!$this->canReadITILItem()) {
          return false;
       }
 
       $problem = new Problem();
       if ($problem->getFromDB($this->fields['problems_id'])) {
-         return (Session::haveRight('problem', UPDATE)
+         return (Session::haveRight(self::$rightname, parent::ADDALLITEM)
+                 || Session::haveRight('problem', UPDATE)
                  || (Session::haveRight('problem', Problem::READMY)
                      && ($problem->isUser(CommonITILActor::ASSIGN, Session::getLoginUserID())
                          || (isset($_SESSION["glpigroups"])
@@ -115,12 +117,13 @@ class ProblemTask extends CommonITILTask {
    **/
    function canUpdateItem() {
 
-      if (!parent::canReadITILItem()) {
+      if (!$this->canReadITILItem()) {
          return false;
       }
 
       if (($this->fields["users_id"] != Session::getLoginUserID())
-          && !Session::haveRight('problem', UPDATE)) {
+          && !Session::haveRight('problem', UPDATE)
+          && !Session::haveRight(self::$rightname, parent::UPDATEALL)) {
          return false;
       }
 
@@ -139,33 +142,21 @@ class ProblemTask extends CommonITILTask {
 
 
    /**
-    * Populate the planning with planned ticket tasks
+    * Populate the planning with planned problem tasks
     *
-    * @param $options   array of possible options:
-    *    - who ID of the user (0 = undefined)
-    *    - who_group ID of the group of users (0 = undefined)
+    * @param $options  array of possible options:
+    *    - who         ID of the user (0 = undefined)
+    *    - whogroup    ID of the group of users (0 = undefined)
     *    - begin Date
     *    - end Date
     *
     * @return array of planning item
    **/
-   static function populatePlanning($options = []) {
+   static function populatePlanning($options = []) :array {
       return parent::genericPopulatePlanning(__CLASS__, $options);
    }
 
 
-   /**
-    * Display a Planning Item
-    *
-    * @param array $val Array of the item to display
-    *
-    * @return string Already planned information
-   **/
-   static function getAlreadyPlannedInformation($val) {
-      return parent::genericGetAlreadyPlannedInformation(__CLASS__, $val);
-   }
-
-
    /**
     * Display a Planning Item
     *
@@ -180,5 +171,20 @@ class ProblemTask extends CommonITILTask {
       return parent::genericDisplayPlanningItem(__CLASS__, $val, $who, $type, $complete);
    }
 
+   /**
+    * Populate the planning with not planned problem tasks
+    *
+    * @param $options  array of possible options:
+    *    - who         ID of the user (0 = undefined)
+    *    - whogroup    ID of the group of users (0 = undefined)
+    *    - begin Date
+    *    - end Date
+    *
+    * @return array of planning item
+   **/
+   static function populateNotPlanned($options = []) :array {
+      return parent::genericPopulateNotPlanned(__CLASS__, $options);
+   }
+
 
 }
