@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -166,16 +166,15 @@ class Report extends CommonGLPI{
     * @since 0.84
    **/
    static function showDefaultReport() {
-      global $DB;
+      global $DB, $CFG_GLPI;
 
       // Title
       echo "<span class='big b'>GLPI ".Report::getTypeName(Session::getPluralNumber())."</span><br><br>";
 
       // 1. Get counts of itemtype
-      $items     = ['Computer', 'Monitor', 'NetworkEquipment', 'Peripheral', 'Phone',
-                         'Printer', 'Software'];
+      $items     = $CFG_GLPI["asset_types"];
 
-      $linkitems = ['Monitor', 'Peripheral', 'Phone', 'Printer'];
+      $linkitems = $CFG_GLPI['directconnect_types'];
 
       echo "<table class='tab_cadrehov'>";
 
@@ -244,7 +243,6 @@ class Report extends CommonGLPI{
       // Get counts of types
 
       $val   = array_flip($items);
-      unset($val["Software"]);
       $items = array_flip($val);
 
       foreach ($items as $itemtype) {
@@ -304,7 +302,7 @@ class Report extends CommonGLPI{
 
 
    /**
-    * Get report informations
+    * Get report information
     *
     * @param string $from      From table
     * @param array  $joincrit  Join criteria
