@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -820,7 +820,7 @@ class SoftwareLicense extends CommonTreeDropdown {
          'name'               => __('Expiration'),
          'forcegroupby'       => true,
          'datatype'           => 'date',
-         'emptylabel'         => 'Never expire',
+         'emptylabel'         => __('Never expire'),
          'massiveaction'      => false,
          'joinparams'         => $licjoinexpire
       ];
@@ -1030,6 +1030,18 @@ class SoftwareLicense extends CommonTreeDropdown {
    }
 
 
+   function getSpecificMassiveActions($checkitem = null) {
+
+      $actions = parent::getSpecificMassiveActions($checkitem);
+      if (static::canUpdate()) {
+         $prefix                       = 'Item_SoftwareLicense'.MassiveAction::CLASS_ACTION_SEPARATOR;
+         $actions[$prefix.'add_item']  = _x('button', 'Add an item');
+      }
+
+      return $actions;
+   }
+
+
    /**
     * Show Licenses of a software
     *
@@ -1048,14 +1060,15 @@ class SoftwareLicense extends CommonTreeDropdown {
       }
 
       $columns = ['name'      => __('Name'),
-                       'entity'    => Entity::getTypeName(1),
-                       'serial'    => __('Serial number'),
-                       'number'    => _x('quantity', 'Number'),
-                       '_affected' => __('Affected items'),
-                       'typename'  => _n('Type', 'Types', 1),
-                       'buyname'   => __('Purchase version'),
-                       'usename'   => __('Version in use'),
-                       'expire'    => __('Expiration')];
+                  'entity'    => Entity::getTypeName(1),
+                  'serial'    => __('Serial number'),
+                  'number'    => _x('quantity', 'Number'),
+                  '_affected' => __('Affected items'),
+                  'typename'  => _n('Type', 'Types', 1),
+                  'buyname'   => __('Purchase version'),
+                  'usename'   => __('Version in use'),
+                  'expire'    => __('Expiration'),
+                  'statename' => __('Status')];
       if (!$software->isRecursive()) {
          unset($columns['entity']);
       }
@@ -1110,7 +1123,8 @@ class SoftwareLicense extends CommonTreeDropdown {
             'buyvers.name AS buyname',
             'usevers.name AS usename',
             'glpi_entities.completename AS entity',
-            'glpi_softwarelicensetypes.name AS typename'
+            'glpi_softwarelicensetypes.name AS typename',
+            'glpi_states.name AS statename'
          ],
          'FROM'      => 'glpi_softwarelicenses',
          'LEFT JOIN' => [
@@ -1137,6 +1151,12 @@ class SoftwareLicense extends CommonTreeDropdown {
                   'glpi_softwarelicensetypes'   => 'id',
                   'glpi_softwarelicenses'       => 'softwarelicensetypes_id'
                ]
+            ],
+            'glpi_states'                       => [
+               'ON' => [
+                  'glpi_softwarelicenses' => 'states_id',
+                  'glpi_states'           => 'id'
+               ]
             ]
          ],
          'WHERE'     => [
@@ -1229,6 +1249,7 @@ class SoftwareLicense extends CommonTreeDropdown {
             echo "<td>".$data['buyname']."</td>";
             echo "<td>".$data['usename']."</td>";
             echo "<td class='center'>".Html::convDate($data['expire'])."</td>";
+            echo "<td>".$data['statename']."</td>";
             echo "</tr>";
 
             if ($data['number'] < 0) {
@@ -1248,7 +1269,7 @@ class SoftwareLicense extends CommonTreeDropdown {
          echo "<td class='numeric'>".(($tot > 0)?$tot."":__('Unlimited')).
                "</td>";
          $color = ($software->fields['is_valid']?'green':'red');
-         echo "<td class='numeric $color'>".$tot_assoc."</td><td></td><td></td><td></td><td></td>";
+         echo "<td class='numeric $color'>".$tot_assoc."</td><td></td><td></td><td></td><td></td><td></td>";
          echo "</tr>";
          echo "</table>\n";
 
