@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -1526,7 +1526,7 @@ class Stat extends CommonGLPI {
             }
             if (is_array($pages) && count($pages)) {
                foreach ($pages as $page => $name) {
-                  $names[$plug.'/'.$page] = ["name" => $name,
+                  $names[Plugin::getWebDir($plug, false).'/'.$page] = ["name" => $name,
                                                   "plug" => $plug];
                   $optgroup[$plug] = Plugin::getInfo($plug, 'name');
                }
@@ -1539,7 +1539,7 @@ class Stat extends CommonGLPI {
          $group = $title;
          foreach ($names as $key => $val) {
             if ($opt == $val["plug"]) {
-               $file                  = $CFG_GLPI["root_doc"]."/plugins/".$key;
+               $file                  = $CFG_GLPI["root_doc"]."/".$key;
                $values[$group][$file] = $val["name"];
                if (stripos($_SERVER['REQUEST_URI'], $file) !== false) {
                   $selected = $file;
@@ -1891,7 +1891,10 @@ class Stat extends CommonGLPI {
             $data = $serie['data'];
             //$labels[$row_num] = $label;
             if (is_array($data) && count($data)) {
-               $headers[$row_num] = $serie['name'];
+               // in case of simple series, we should not have the name
+               if (isset($serie['name'])) {
+                  $headers[$row_num] = $serie['name'];
+               }
                foreach ($data as $key => $val) {
                   if (!isset($values[$key])) {
                      $values[$key] = [];
