@@ -2,7 +2,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2021 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -461,7 +461,7 @@ function step4 ($databasename, $newdatabasename) {
 
 }
 
-//send telemetry informations
+//send telemetry information
 function step6() {
    global $DB;
    echo "<h3>".__('Collect data')."</h3>";
@@ -473,6 +473,7 @@ function step6() {
    echo "<form action='install.php' method='post'>";
    echo "<input type='hidden' name='install' value='Etape_5'>";
 
+   $_SESSION['telemetry_from_install'] = true;
    echo Telemetry::showTelemetry();
    echo Telemetry::showReference();
 
@@ -676,7 +677,7 @@ if (!isset($_SESSION['can_process_install']) || !isset($_POST["install"])) {
                $_POST["newdatabasename"]);
          break;
 
-      case "Etape_4" : // send telemetry informations
+      case "Etape_4" : // send telemetry information
          header_html(sprintf(__('Step %d'), 4));
          step6();
          break;
