@@ -4,7 +4,7 @@
 /**
  * ---------------------------------------------------------------------
  * GLPI - Gestionnaire Libre de Parc Informatique
- * Copyright (C) 2015-2018 Teclib' and contributors.
+ * Copyright (C) 2015-2022 Teclib' and contributors.
  *
  * http://glpi-project.org
  *
@@ -34,6 +34,8 @@
 
 include ('../inc/includes.php');
 
+echo "Usage of this script is deprecated, please use 'php bin/console rules:process_software_category_rules' command.\n";
+
 // COMPUTER ONLY UNDEF CATEGORIES
 $ONLY_UNDEFINED = true;
 
@@ -46,7 +48,7 @@ $query = "SELECT `id`, `softwarecategories_id`
 
 if ($result=$DB->query($query)) {
    if ($DB->numrows($result)>0) {
-      while ($data=$DB->fetch_array($result)) {
+      while ($data=$DB->fetchArray($result)) {
          if (!$ONLY_UNDEFINED || $data['softwarecategories_id']==0) {
             $params = [];
 
